<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl"
    exclude-result-prefixes="xs xd"
    version="2.0">
    <xd:doc scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Created on:</xd:b> Nov 7, 2012</xd:p>
            <xd:p><xd:b>Author:</xd:b> ahenket</xd:p>
            <xd:p></xd:p>
        </xd:desc>
    </xd:doc>
    
    <xsl:output method="text"/>
    <!-- sh or bat -->
    <xsl:param name="batchType"/>
    <!-- interactionId to copy resources for AAAA_INnnnnnn... -->
    <xsl:param name="interactionId" required="yes"/>
    <xsl:variable name="interactionIds" select="replace($interactionId,'&quot;','')"/>
    <!-- Directory to write message types to, and where the converted interactions files should already be -->
    <xsl:param name="outputDir"/>
    <!-- Generated file that contains all includes per file  -->
    <xsl:param name="xmlschemainfo" select="'../resolveIncludes/xmlschemainfo.xml'"/>
    <!-- Convert backslashes to forward slashes -->
    <xsl:variable name="outputdirectory" select="replace(translate($outputDir,'\\','/'),'/$','')"/>
    
    <xsl:variable name="pathSep">
        <xsl:choose>
            <xsl:when test="$batchType='bat'">
                <xsl:text>bat</xsl:text>
            </xsl:when>
            <xsl:when test="$batchType='sh'">
                <xsl:text>sh</xsl:text>
            </xsl:when>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="lineSep">
        <xsl:choose>
            <xsl:when test="$batchType='bat'">
                <xsl:text>&#13;&#10;</xsl:text>
            </xsl:when>
            <xsl:when test="$batchType='sh'">
                <xsl:text>&#10;</xsl:text>
            </xsl:when>
        </xsl:choose>
    </xsl:variable>
    
    <!-- Walk through all file element that use the interaction, taking all child uses elements into account in step 1. 
        This creates duplicates that we avoid in step 2 when we create the definite content of includeList -->
    <xsl:variable name="includeList">
        <xsl:call-template name="checkParameters"/>
        <xsl:variable name="tempList">
            <includes>
                <xsl:for-each select="tokenize($interactionIds,' ')">
                    <xsl:variable name="interactionFile" select="concat(.,'.xsd')"/>
                    <xsl:variable name="interactionPattern" select="concat('^',.,'\\.xsd$')"/>
                    
                    <xsl:for-each select="document($xmlschemainfo)/*/file[@file=$interactionFile] | document($xmlschemainfo)/*/file[@file=$interactionFile or used-in[@file=$interactionFile]]/uses">
                        <xsl:variable name="docUri" select="@full"/>
                        <xsl:variable name="docFileName" select="@file"/>
                        <xsl:if test="not(contains($docUri,'coreschemas'))">
                            <include schemaLocation="{$docUri}" schemaFileName="{$docFileName}"/>
                        </xsl:if>
                    </xsl:for-each>
                </xsl:for-each>
            </includes>
        </xsl:variable>
        <includes>
            <!-- Copy avoiding duplicate copy -->
            <xsl:copy-of select="$tempList/*/include[not(@schemaFileName=preceding-sibling::include/@schemaFileName)]"/>
        </includes>
    </xsl:variable>
    
    <xsl:template match="/">
        <xsl:call-template name="checkParameters"/>
        <!--xsl:message terminate="no"><xsl:copy-of select="$includeList"/></xsl:message-->
        <xsl:choose>
            <xsl:when test="$batchType='sh'">
                <xsl:text>#!/bin/sh</xsl:text>
                <xsl:value-of select="$lineSep"/>
            </xsl:when>
            <xsl:when test="$batchType='bat'">
                <xsl:text>@echo off</xsl:text>
                <xsl:value-of select="$lineSep"/>
            </xsl:when>
        </xsl:choose>
        <xsl:value-of select="$lineSep"/>
        <xsl:for-each select="$includeList/*/include">
            <xsl:sort select="@schemaFileName"/>
            <xsl:choose>
                <xsl:when test="$batchType='sh'">
                    <xsl:value-of select="concat('echo &quot;    Copy ',@schemaFileName,'&quot;',$lineSep)"/>
                    <xsl:value-of select="concat('cp -p ',@schemaLocation,' ',$outputdirectory,'/',$lineSep)"/>
                </xsl:when>
                <xsl:when test="$batchType='bat'">
                    <xsl:value-of select="concat('echo.    Copy ',@schemaFileName,$lineSep)"/>
                    <xsl:value-of select="concat('copy /y ',@schemaLocation,' ',translate($outputdirectory,'/','\\'),'\',$lineSep)"/>
                </xsl:when>
            </xsl:choose>
        </xsl:for-each>
    </xsl:template>
    
    <!-- Check input parameters to this transformation -->
    <xsl:template name="checkParameters">
        <xsl:variable name="errorMessage">
            <xsl:if test="not($batchType='sh' or $batchType='bat')">
                <xsl:value-of select="concat('ERROR Parameter batchType &quot;',$batchType,'&quot; should be &quot;sh&quot; or &quot;bat&quot;.&#xa;')"/>
            </xsl:if>
            <xsl:for-each select="tokenize($interactionIds,' ')">
                <xsl:if test="not(matches(.,'^[A-Z]{4}_IN[0-9]{6}'))">
                    <xsl:value-of select="concat('ERROR Parameter interactionId &quot;',.,'&quot; does not match pattern AAAA_INnnnnnn &#xa;')"/>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="tokenize($interactionIds,' ')">
                <xsl:variable name="interactionFile" select="concat(.,'.xsd')"/>
                <xsl:variable name="interactionPattern" select="concat('^',.,'\\.xsd$')"/>
                
                <xsl:if test="not(document($xmlschemainfo)/*/file[@file=$interactionFile])">
                    <xsl:value-of select="concat('ERROR Parameter interactionId &quot;',.,'&quot; does not exist (according to ',$xmlschemainfo,')&#xa;')"/>
                </xsl:if>
            </xsl:for-each>
            <xsl:if test="ends-with($outputdirectory,'/')">
                <xsl:value-of select="concat('ERROR Parameter outputDir should not have a trailing (back)slash. Found &quot;',$outputDir,'&quot;&#xa;')"/>
            </xsl:if>
        </xsl:variable>
        <xsl:if test="$errorMessage!=''">
            <xsl:message terminate="yes" select="$errorMessage"/>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>