#!/bin/sh

# -----------------------------------------
# --  set defaults                       --
# -----------------------------------------

# These are used on the command line
export outputSchemaInfoFile=../resolveIncludes/xmlschemainfo.xml
export interactionId=${1}
export outputCopyFile=./copyScript.sh
export outputDir=CopiedSchemas

# These are used on the command line and must contain a forward slash in path
export jarDir=../lib
export xslDir=.

# -------------------------------------------
# --  use input params instead of defaults --
# --  if given                             --
# -------------------------------------------

if [ -d "$1" ]; then
    echo ERROR Need to supply an interaction id like MFMT_IN200101 or QUPC_IN101101UV02!
    exit
fi

echo "Input/output schema info file                       = ${outputSchemaInfoFile}"
echo "File with copy statements                           = ${outputCopyFile}"
echo "Directory that the schema files will be copied to   = ${outputDir}"
echo "Java jar path                                       = $jarDir"
echo "XSL path                                            = $xslDir"

# -------------------------------------------
# --  check input and output dirs          --
# --                                       --
# -------------------------------------------

if [ -e "${outputCopyFile}" ]; then
    echo "\nDeleting previous ${outputCopyFile}..."
    rm "${outputCopyFile}"
fi

if [ ! -e "${outputDir}" ]; then 
    echo "\nCreating output directory ${outputDir}..."
    mkdir "${outputDir}"
fi
if [ -e "${outputDir}/*" ]; then 
    echo "\nDeleting contents of output directory ${outputDir}..."
    rm ${outputDir}/*.*
fi

# -------------------------------------------
# --  generate output                      --
# --                                       --
# -------------------------------------------

echo "Building list of includes per XML Schema..."
echo ""
../resolveIncludes/buildXmlSchemaInfoForDir.sh

echo "\nCreating copy script..."
java -jar ${jarDir}/saxon-9/saxon9.jar -s:${xslDir}/copySchemasForInteraction.xsl -xsl:${xslDir}/copySchemasForInteraction.xsl -o:${outputCopyFile} interactionId="${interactionId}" batchType=sh outputDir=${outputDir} xmlschemainfo=${outputSchemaInfoFile}

if [ -e "${outputCopyFile}" ]; then
    echo "\nMaking copy script executable..."
    chmod u+x ${outputCopyFile}

    echo "\nExecuting copy script..."
    ${outputCopyFile}
    
    echo "\nDeleting copy script..."
    rm "${outputCopyFile}"
    
    echo "\nSUCCESS: Find copied files in directory ${outputDir}"
else
    echo "\nFAILED: Please check log above this line for errors"
fi
