<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" xmlns:hl7="urn:hl7-org:v3" exclude-result-prefixes="#all" xmlns:File="java:java.io.File" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:sch="http://purl.oclc.org/dsdl/schematron">
    <!-- 
        This stylesheet creates the main html index for the documentation of the XML distribution.
        The content is organised into five tabs:
        1. Introduction
        2. WSDL, index of all wsdl files in the WSDL directory
        3. Schemas, index of the XML schemas
        4. Vocabulary, index of of files in the vocab directory
        5. Directory Overview, index of the XML distribution with description of directories.
    
        This stylesheet requires the Saxon XSLT2 processor 9 HE
        
        Copyright notice .....
        
        Authors ....?
    -->
    <xsl:output method="html" indent="yes" version="4.01" encoding="UTF-8" doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd"/>
    <!-- parameters for directory paths -->
    <xsl:param name="mepPath" select="'../wsdlProcess/mep/'"/>
    <xsl:param name="inputdir" select="'../../schemas'"/>
    <xsl:param name="inputXML" select="'../..'"/>
    <xsl:param name="inputdirSchematron" select="'../../schematron'"/>
    <xsl:param name="inputdirVocab" select="'../../vocab'"/>
    <xsl:param name="visioInfoFile" select="'visiomodelindex.xml'"/>
    <xsl:param name="schemaInfoFile" select="'../resolveIncludes/xmlschemainfo.xml'"/>
    <xsl:param name="aortaRelease" required="yes"/>
    <xsl:param name="language" select="'nl-NL'"/>
    <xsl:variable name="visioInfoFileNormalized" select="replace($visioInfoFile,'\\','/')"/>
    <xsl:variable name="schemaInfoFileNormalized" select="replace($schemaInfoFile,'\\','/')"/>

    <xsl:variable name="interactionVocabFile" select="concat($inputdirVocab,'/2.16.840.1.113883.1.6.xml')"/>
    <xsl:variable name="hmd">
        <files>
            <file name="MCAI_MT700201" rmim="MCAI_RM700200"/>
            <file name="MCAI_MT700201_OPT_OV" rmim="MCAI_RM700200"/>
            <file name="MCAI_MT900001" rmim="MCAI_RM900000"/>
            <file name="MFMI_MT700701" rmim="MFMI_RM700700"/>
            <file name="MFMI_MT700701_OPT_OV" rmim="MFMI_RM700700"/>
            <file name="MFMI_MT700702" rmim="MFMI_RM700700"/>
            <file name="MFMI_MT700702_OPT_OV" rmim="MFMI_RM700700"/>
            <file name="MFMI_MT700711" rmim="MFMI_RM700710"/>
            <file name="MFMI_MT700712" rmim="MFMI_RM700710"/>
            <file name="MFMT_MT002001" rmim="MFMT_RM002000"/>
            <file name="MFMT_MT002001NL02" rmim="MFMT_RM002000NL02"/>
            <file name="MFMT_MT002002" rmim="MFMT_RM002000"/>
            <file name="MFMT_MT002002NL02" rmim="MFMT_RM002000NL02"/>
            <file name="PRPM_MT405010NL" rmim="PRPM_RM405000NL"/>
            <file name="PRPM_MT406010NL" rmim="PRPM_RM406000NL"/>
            <file name="PRPM_MT906010NL" rmim="PRPM_RM906000NL"/>
            <file name="PRPM_MT906110NL" rmim="PRPM_RM901000NL"/>
            <file name="QUQI_MT020001" rmim="QUQI_RM020000"/>
            <file name="QUQI_MT021001" rmim="QUQI_RM021000"/>
            <file name="QUQI_MT021001_OPT_OV" rmim="QUQI_RM021000"/>
            <file name="QUQI_MT120001" rmim="QUQI_RM120000"/>
        </files>
    </xsl:variable>
    
    <xsl:variable name="dirTestSchemas" select="File:new(resolve-uri($inputdir))"/>
    <xsl:variable name="dirTestVocab" select="File:new(resolve-uri($inputdirVocab))"/>
    <xsl:variable name="wsdlGBZ" select="File:new(concat($inputXML,'/wsdl/index.html'))"/>
    <xsl:variable name="wsdlGBP" select="File:new(concat($inputXML,'/wsdl-GBP/index.html'))"/>
    <xsl:variable name="wsdlGBK" select="File:new(concat($inputXML,'/wsdl-GBK/index.html'))"/>
    <xsl:variable name="wsdlGBO" select="File:new(concat($inputXML,'/wsdl-GBO/index.html'))"/>
    
    <!-- TODO: complete list -->
    <xsl:variable name="lang">
        <key k="docTitle"><value xml:lang="nl-NL">Documentatie voor de Nictiz XML-materialen</value><value xml:lang="en-US">Documentation for the Nictiz XML materials</value></key>
        <key k="pgTitle"><value xml:lang="nl-NL">Nictiz XML-distributie</value><value xml:lang="en-US">Nictiz XML distribution</value></key>
        <key k="Generated"><value xml:lang="nl-NL">Gegenereerd: </value><value xml:lang="en-US">Generated: </value></key>
    </xsl:variable>
    
    <!--store variables-->
    <xsl:variable name="defaultMessage">MCCI_IN000002</xsl:variable>
    <xsl:variable name="schemaPath">schemas_codeGen/</xsl:variable>
    <xsl:variable name="wsdlPath">wsdl/</xsl:variable>
    <xsl:template match="/">
        <html>
            <head>
                <title>Documentatie voor de Nictiz XML-materialen</title>
                <xsl:call-template name="addAssetsHeader"/>
            </head>
            <body>
                <!-- page header -->
                <table width="100%">
                    <tr>
                        <td valign="bottom">
                            <h1>Nictiz XML-distributie <xsl:value-of select="$aortaRelease"/></h1> Gegenereerd: <xsl:value-of select="format-date(current-date(), '[D,2] [MNn] [Y]')"/>
                        </td>
                        <td align="right">
                            <div class="logo"/>
                        </td>
                    </tr>
                </table>
                <p/>
                <!-- Spry tabbed panels -->
                <div id="TabbedPanels2" class="TabbedPanels">
                    <!-- tab labels -->
                    <ul class="TabbedPanelsTabGroup">
                        <li class="TabbedPanelsTab" tabindex="0" style="font-size:14px">Inleiding</li>
                        <xsl:if test="File:isFile($wsdlGBZ) or File:isFile($wsdlGBO) or File:isFile($wsdlGBP) or File:isFile($wsdlGBK)">
                            <li class="TabbedPanelsTab" tabindex="1" style="font-size:14px">Webservices</li>
                        </xsl:if>
                        <xsl:if test="File:isDirectory($dirTestSchemas)">
                            <li class="TabbedPanelsTab" tabindex="2" style="font-size:14px">Schema's</li>
                        </xsl:if>
                        <li class="TabbedPanelsTab" tabindex="3" style="font-size:14px">Schematrons</li>
                        <xsl:if test="File:isDirectory($dirTestVocab)">
                            <li class="TabbedPanelsTab" tabindex="4" style="font-size:14px">Vocabulaires</li>
                        </xsl:if>
                        <li class="TabbedPanelsTab" tabindex="5" style="font-size:14px">Overzicht mappen</li>
                    </ul>
                    <!-- tab Group -->
                    <div class="TabbedPanelsContentGroup">
                        <!-- INTRO tab -->
                        <div class="TabbedPanelsContent">
                            <table>
                                <tr>
                                    <td class="content">
                                        <p>Welkom bij de HTML-documentatie van de XML-distributie.</p>
                                        <p>Tips bij het gebruik:</p>
                                        <ul>
                                            <li>Bij tabellen kan de inhoud naar wens gesorteerd worden door op één van de kolombeschrijvingen te klikken, het kleine rode pijltje geeft aan hoe gesorteerd wordt.</li>
                                            <li>De Webservices tab is meer dan alleen een opsomming van alle webservices, het is ook een handige ingang naar achterliggende XML schema's en XML-voorbeeldberichten.</li>
                                        </ul>
                                        <p>Nictiz is voor nieuwere projecten/standaarden overgeschakeld naar een nieuwe methodiek <b>DECOR</b>. Nictiz onderhoudt op basis hiervan alle huidige en toekomstige materialen op een openbaar toegankelijke server <a href="http://decor.nictiz.nl/art-decor">decor.nictiz.nl/art-decor</a>. De doelen en de achtergrond van deze open source methodiek, vindt u hier:</p>
                                        <ul>
                                            <li>
                                                <a href="http://decor.nictiz.nl">Nictiz' ART-DECOR Wiki</a>
                                            </li>
                                            <li>
                                                <a href="http://www.art-decor.org">Thuisbasis voor ART-DECOR</a>
                                            </li>
                                            <li>
                                                <a href="https://sourceforge.net/p/artdecor">Sourceforge project voor ART-DECOR</a>
                                            </li>
                                        </ul>
                                        <p>Deze omschakeling betekent voor de XML schema's en webservices nog niets, maar HL7v3-interacties zullen vaker gebruik maken van templateId's en schematronbestanden en vocabulaire zullen anders van opbouw zijn. Standaarden gebaseerd op DECOR hebben volledig gegenereerde schematrons en vocabulairebestanden.</p>
                                    </td>
                                </tr>
                            </table>
                        </div>
                        <!-- WSDL GBZ tab -->
                        <xsl:if test="File:isFile($wsdlGBZ) or File:isFile($wsdlGBO) or File:isFile($wsdlGBP) or File:isFile($wsdlGBK)">
                            <div class="TabbedPanelsContent">
                                <table>
                                    <tr>
                                        <td class="content">
                                            <table>
                                                <tr>
                                                    <td>
                                                        <div class="level2">
                                                            <div class="paragraph">Hieronder een overzicht van alle Webservices (met link naar de documentatie) met hun WSDL. In alle gevallen is de WSDL de normatieve beschrijving van de Webservice en is de documentatie aanvullend. De derde kolom toont de interactieschema's van de berichten die in de webservice gebruikt worden.</div>
                                                            <xsl:call-template name="wsdlFileList"/>
                                                        </div>
                                                    </td>
                                                </tr>
                                            </table>
                                        </td>
                                    </tr>
                                </table>
                            </div>
                        </xsl:if>
                        <!-- Schemas tab -->
                        <xsl:if test="File:isDirectory($dirTestSchemas)">
                            <div class="TabbedPanelsContent">
                                <table width="100%">
                                    <tr>
                                        <td class="content">
                                            <table width="100%">
                                                <tr>
                                                    <td>
                                                        <div class="paragraph">
                                                            <xsl:text>Hieronder een overzicht van alle </xsl:text>
                                                            <xsl:value-of select="count(document($schemaInfoFileNormalized)/*/file)"/>
                                                            <xsl:text> XML schema's, waarvan </xsl:text>
                                                            <xsl:value-of select="count(document($schemaInfoFileNormalized)/*/file[matches(@file,'^[A-Z]{4}_IN')])"/>
                                                            <xsl:text> interacties. De schema's zijn per HL7-domein, zichtbaar in de eerste vier letters, gegroepeerd en worden voorafgegaan door het overzicht van interacties. De interacties komen ook terug in de HL7-domeingroepen.</xsl:text>
                                                        </div>
                                                        <xsl:call-template name="schemaFileList"/>
                                                    </td>
                                                </tr>
                                            </table>
                                        </td>
                                    </tr>
                                </table>
                            </div>
                        </xsl:if>
                        <!-- Schematrons tab -->
                        <div class="TabbedPanelsContent">
                            <table>
                                <tr>
                                    <td class="content">
                                        <table>
                                            <tr>
                                                <td>
                                                    <div class="level2">
                                                        <div class="paragraph">Hieronder een overzicht van alle Schematrons. Schematronbestanden van het type "<i>interactie-id</i>.sch" horen bij de oorspronkelijke methodiek. Schematronbestanden van het type "<i>prefix-omschrijving</i>.sch" zijn gegenereerd uit een DECOR-definitie.</div>
                                                        <xsl:call-template name="schematronFileList"/>
                                                    </div>
                                                </td>
                                            </tr>
                                        </table>
                                    </td>
                                </tr>
                            </table>
                        </div>
                        <!-- Vocabulary tab -->
                        <xsl:if test="File:isDirectory($dirTestVocab)">
                            <div class="TabbedPanelsContent">
                                <table>
                                    <tr>
                                        <td class="content">
                                            <table>
                                                <tr>
                                                    <td>
                                                        <div class="level2">
                                                            <div class="paragraph">
                                                                <xsl:text>Overzicht van de binnen de map vocab gebruikte vocabulaires. De via de 
                                                            DECOR-methodiek (zie tabblad Inleiding) gegenereerde vocabulairebestanden staan in 
                                                            schematron/include en zijn niet hier gedocumenteerd, maar in de betreffende projectdocumentatie.
                                                            Naarmate meer projecten worden ge/herschreven in DECOR zal het aantal hier genoemde vocabulaires
                                                            afnemen. Het complete overzicht van door Nictiz gedefinieerde vocabulaire vindt u hier: </xsl:text>
                                                                <a href="http://decor.nictiz.nl/decor/services/ValueSetIndex">http://decor.nictiz.nl/decor/services/ValueSetIndex</a>
                                                                <p> N.B. Vocabulaires die niet door Nictiz worden beheerd zijn zuiver informatief. Zij zijn opgenomen voor gebruik door de schematron en html presentatie stylesheets, meldingen moeten gezien worden waarschuwingen.</p>
                                                            </div>
                                                            <xsl:call-template name="vocabFileList"/>
                                                        </div>
                                                    </td>
                                                </tr>
                                            </table>
                                        </td>
                                    </tr>
                                </table>
                            </div>
                        </xsl:if>
                        <!-- Overview Directories tab -->
                        <div class="TabbedPanelsContent">
                            <table>
                                <tr>
                                    <td class="content">
                                        <div class="level2">
                                            <div class="paragraph">Het onderstaande overzicht bevat beschrijvingen van de mappen in de XML-distributie. Klikken op een map gaat rechtstreeks naar de desbetreffende map.</div>
                                            <xsl:call-template name="fileList">
                                                <xsl:with-param name="descriptions" select="descriptions"/>
                                            </xsl:call-template>
                                        </div>
                                    </td>
                                </tr>
                            </table>
                        </div>
                    </div>
                </div>
                <xsl:call-template name="addAssetsBottom"/>
            </body>
        </html>
    </xsl:template>

    <!-- template for creating list of WSDL descriptions -->
    <xsl:template name="wsdlFileList">
        <xsl:message>Building WSDL file list ...</xsl:message>
        <table class="values" id="wsdlList">
            <thead>
                <tr>
                    <th class="larger">Naam</th>
                    <th class="larger">Omschrijving</th>
                </tr>
            </thead>
            <xsl:if test="File:isFile($wsdlGBZ)">
                <xsl:message> - Adding link to wsdl/index.html ...</xsl:message>
                <tr>
                    <td class="value">
                        <xsl:element name="a">
                            <xsl:attribute name="href" select="'wsdl/index.html'"/>
                            <xsl:text>Webservices GBZ</xsl:text>
                        </xsl:element>
                    </td>
                    <td class="value"> Indexbestand voor webservices ten behoeve van een Goed Beheerd Zorgsysteem (GBZ) </td>
                </tr>
            </xsl:if>
            <!--xsl:if test="doc-available(concat($inputXML,'/wsdl-GBP/index.html'))"-->
            <xsl:if test="File:isFile($wsdlGBP)">
                <xsl:message> - Adding link to wsdl-GBP/index.html ...</xsl:message>
                <tr>
                    <td class="value">
                        <xsl:element name="a">
                            <xsl:attribute name="href" select="'wsdl-GBP/index.html'"/>
                            <xsl:text>Webservices GBP</xsl:text>
                        </xsl:element>
                    </td>
                    <td class="value"> Indexbestand voor webservices ten behoeve van een Patiëntenportaal (GBP) </td>
                </tr>
            </xsl:if>
            <!--xsl:if test="doc-available(concat($inputXML,'/wsdl-GBK/index.html'))"-->
            <xsl:if test="File:isFile($wsdlGBK)">
                <xsl:message> - Adding link to wsdl-GBK/index.html ...</xsl:message>
                <tr>
                    <td class="value">
                        <xsl:element name="a">
                            <xsl:attribute name="href" select="'wsdl-GBK/index.html'"/>
                            <xsl:text>Webservices GBK</xsl:text>
                        </xsl:element>
                    </td>
                    <td class="value"> Indexbestand voor webservices ten behoeve van het Klantenloket (GBK) </td>
                </tr>
            </xsl:if>
            <!--xsl:if test="doc-available(concat($inputXML,'/wsdl-GBO/index.html'))"-->
            <xsl:if test="File:isFile($wsdlGBO)">
                <xsl:message> - Adding link to wsdl-GBO/index.html ...</xsl:message>
                <tr>
                    <td class="value">
                        <xsl:element name="a">
                            <xsl:attribute name="href" select="'wsdl-GBO/index.html'"/>
                            <xsl:text>Webservices GBO</xsl:text>
                        </xsl:element>
                    </td>
                    <td class="value"> Indexbestand voor webservices ten behoeve van een Goed Beheerde Organisatie (GBO) op basis van PKIO-authenticatie</td>
                </tr>
            </xsl:if>
        </table>
    </xsl:template>

    <!-- template for creating list of directory descriptions -->
    <xsl:template name="fileList">
        <xsl:param name="descriptions"/>
        <xsl:variable name="directory" select="resolve-uri('../..')" as="xs:anyURI"/>
        <xsl:variable name="dir" select="File:new($directory)"/>
        <xsl:variable name="files" select="File:list($dir)"/>
        <table class="values" id="directoryList">
            <thead>
                <tr>
                    <th class="larger">Map/bestand</th>
                    <th class="larger">Omschrijving</th>
                </tr>
            </thead>
            <!-- Handle case where pdf is not created yet, but doc is available -->
            <xsl:for-each select="$files[ends-with(.,'XML_materiaal_Erratum.doc')]">
                <xsl:variable name="name" select="."/>
                <xsl:variable name="namepdf" select="concat(substring($name,0,string-length($name)-2),'pdf')"/>
                <xsl:variable name="folder" select="$descriptions/folder[@name=$name]"/>
                <xsl:if test="not($files[.=$namepdf])">
                    <tr>
                        <td class="value">
                            <a href="{$name}">
                                <xsl:value-of select="$name"/>
                            </a>
                        </td>
                        <td class="value">
                            <xsl:copy-of select="$folder/description[@xml:lang=$language]/div"/>
                        </td>
                    </tr>
                </xsl:if>
            </xsl:for-each>
            <xsl:for-each select="$files">
                <xsl:if test="not(starts-with(.,'.')) and not(.=('index.html','tools_internal') or ends-with(.,'XML_materiaal_Erratum.doc'))">
                    <tr>
                        <xsl:variable name="folderName" select="."/>
                        <xsl:variable name="folder" select="if ($descriptions/folder[@name=$folderName]) then $descriptions/folder[@name=$folderName] else $descriptions/folder[@ends-with][ends-with($folderName,@ends-with)]"/>
                        <td class="value">
                            <a href="{$folderName}">
                                <xsl:value-of select="$folderName"/>
                            </a>
                        </td>
                        <td class="value">
                            <xsl:copy-of select="$folder/description[@xml:lang=$language]/div"/>
                        </td>
                    </tr>
                </xsl:if>
            </xsl:for-each>
        </table>
    </xsl:template>

    <!-- template for creating list of schemas directory content -->
    <xsl:template name="schemaFileList">
        <xsl:variable name="schemaCollection" select="collection(iri-to-uri(concat(resolve-uri($inputdir),'?select=', '*.xsd;recurse=no')))"/>

        <xsl:variable name="groupHeader" select="'Interacties'"/>
        <xsl:variable name="id" select="concat('int_',generate-id())"/>
        <xsl:variable name="id-toggler" select="concat($id,'-toggler')"/>
        <xsl:element name="h2">
            <xsl:attribute name="class" select="'toggler'"/>
            <xsl:attribute name="id" select="$id-toggler"/>
            <xsl:attribute name="onclick" select="concat('return toggle(&quot;',$id,'&quot;,&quot;',$id-toggler,'&quot;)')"/>
            <xsl:value-of select="$groupHeader"/>
        </xsl:element>
        <div class="level2">
            <xsl:element name="div">
                <xsl:attribute name="id" select="$id"/>
                <xsl:attribute name="class" select="'toggle'"/>
                <!-- create tabel element for group, id needs to be set runtime -->
                <xsl:element name="table">
                    <xsl:attribute name="class" select="'values'"/>
                    <xsl:attribute name="id" select="concat($groupHeader,'schemaList')"/>

                    <thead>
                        <tr>
                            <th class="larger" title="Bestandsnaam XML Schema">XML Schema</th>
                            <th class="larger" title="R-MIM bevat de volgende naam en omschrijving">Omschrijving</th>
                            <th class="larger" title="Schema bevat de volgende include(s), die mogelijk zelf ook weer includes bevatten">Includes</th>
                            <th class="larger" title="Schema wordt gebruikt in de volgende interactie(s)">Interactie</th>
                        </tr>
                    </thead>
                    <xsl:for-each select="$schemaCollection[matches(tokenize(document-uri(.), '/')[last()],'^.{4}_IN')]">
                        <xsl:sort/>
                        <xsl:variable name="fullDirName" select="document-uri(.)"/>
                        <xsl:variable name="fileName" select="tokenize(document-uri(.), '/')[last()]"/>
                        <xsl:variable name="dirName" select="tokenize(document-uri(.), '/')[last()-1]"/>
                        <tr>
                            <td class="value">
                                <xsl:element name="a">
                                    <xsl:attribute name="name">
                                        <xsl:value-of select="$fileName"/>
                                    </xsl:attribute>
                                </xsl:element>
                                <xsl:element name="a">
                                    <xsl:attribute name="href">
                                        <xsl:value-of select="concat($dirName,'/',$fileName)"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="$fileName"/>
                                </xsl:element>
                            </td>
                            <td class="value">
                                <xsl:variable name="fileDescription">
                                    <xsl:call-template name="getDescriptionForSchema">
                                        <xsl:with-param name="schemaFileName" select="$fileName"/>
                                    </xsl:call-template>
                                </xsl:variable>
                                <xsl:choose>
                                    <xsl:when test="$fileDescription and not($fileDescription='')">
                                        <!-- START DEBUG INFO -->
                                        <xsl:if test="contains($fileName,'_MT')">
                                            <xsl:variable name="schemaBaseName" select="replace(substring-before($fileName,'.'),'_MT','_RM')"/>
                                            <xsl:variable name="visioLocation" select="document($visioInfoFileNormalized)/*/file[@name=concat($schemaBaseName,'.xml')][1]/@relpath"/>
                                            <xsl:comment> (DEBUG) Visio location: <xsl:value-of select="$visioLocation"/></xsl:comment>
                                        </xsl:if>
                                        <!-- END DEBUG INFO -->
                                        <xsl:value-of select="$fileDescription"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <!-- START DEBUG INFO -->
                                        <xsl:variable name="schemaBaseName" select="replace(substring-before($fileName,'.'),'_MT','_RM')"/>
                                        <xsl:comment> (DEBUG) Visio missing: <xsl:value-of select="concat($schemaBaseName,'.xml')"/>
                                            </xsl:comment>
                                        <!-- END DEBUG INFO -->
                                        <xsl:text>Omschrijving ontbreekt</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </td>
                            <td class="value">
                                <xsl:variable name="includes" select="document($fullDirName)/xs:schema/xs:include"/>
                                <xsl:for-each select="$includes">
                                    <xsl:variable name="schemaLocation" select="@schemaLocation"/>
                                    <div>
                                        <xsl:choose>
                                            <xsl:when test="contains($schemaLocation,'coreschemas') or $dirName='coreschemas'">
                                                <xsl:element name="a">
                                                    <xsl:attribute name="href">
                                                        <xsl:value-of select="concat('intro/coreschemas.html#',tokenize($schemaLocation, '/')[last()])"/>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="$schemaLocation"/>
                                                </xsl:element>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:element name="a">
                                                    <xsl:attribute name="href">
                                                        <xsl:value-of select="concat('#',$fileName)"/>
                                                    </xsl:attribute>
                                                    <xsl:value-of select="$schemaLocation"/>
                                                </xsl:element>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </div>
                                </xsl:for-each>
                            </td>
                            <td class="value">
                                <xsl:for-each select="document($schemaInfoFileNormalized)//file[@file=$fileName]/used-in[matches(@file,'[A-Z]{4}_IN')]">
                                    <xsl:sort select="@file"/>
                                    <xsl:variable name="currentFile" select="@file"/>
                                    <div>
                                        <xsl:element name="a">
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="concat('#',$currentFile)"/>
                                            </xsl:attribute>
                                            <xsl:value-of select="$currentFile"/>
                                        </xsl:element>
                                    </div>
                                </xsl:for-each>
                            </td>
                        </tr>
                    </xsl:for-each>
                </xsl:element>
            </xsl:element>
        </div>
        <xsl:for-each-group group-by="tokenize(tokenize(document-uri(.), '/')[last()],'_')[1]" select="$schemaCollection">
            <xsl:variable name="fileName" select="tokenize(document-uri(.), '/')[last()]"/>
            <xsl:variable name="groupName" select="tokenize($fileName,'_')[1]"/>
            <xsl:variable name="groupHeader">
                <xsl:choose>
                    <xsl:when test="$groupName='COCT'">
                        <xsl:text>COCT - Common Message Elements</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='COMT'">
                        <xsl:text>COMT - Common Message Content</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='MCAI'">
                        <xsl:text>MCAI - Message Act Infrastructure</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='MCCI'">
                        <xsl:text>MCCI - Message Control Infrastructure</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='MFMI'">
                        <xsl:text>MFMI - Master File Management Infrastructure</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='MFMT'">
                        <xsl:text>MFMT - Master File Message Types</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='POCP'">
                        <xsl:text>POCP - Common Product Model</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='POIZ'">
                        <xsl:text>POIZ - Immunization</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='POLB'">
                        <xsl:text>POLB - Laboratory</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='POOR'">
                        <xsl:text>POOR - Orders</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='PORX'">
                        <xsl:text>PORX - Pharmacy</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='PRMM'">
                        <xsl:text>PRMM - Material Management</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='PRPA'">
                        <xsl:text>PRPA - Patient Administration</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='PRPM'">
                        <xsl:text>PRPM - Personnel Management</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='QUMT'">
                        <xsl:text>QUMT - Query Master File Types</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='QUPA'">
                        <xsl:text>QUMT - Patient Administration</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='QUPC'">
                        <xsl:text>QUPC - Query Care Provision</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='QUQI'">
                        <xsl:text>QUQI - Query Infrastructure</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='QURX'">
                        <xsl:text>QURX - Query Pharmacy</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='RCMR'">
                        <xsl:text>RCMR - Medical Records</xsl:text>
                    </xsl:when>
                    <xsl:when test="$groupName='REPC'">
                        <xsl:text>REPC - Care Provision</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$groupName"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <xsl:variable name="id" select="generate-id()"/>
            <xsl:variable name="id-toggler" select="concat($id,'-toggler')"/>
            <xsl:element name="h2">
                <xsl:attribute name="class" select="'toggler'"/>
                <xsl:attribute name="id" select="$id-toggler"/>
                <xsl:attribute name="onclick" select="concat('return toggle(&quot;',$id,'&quot;,&quot;',$id-toggler,'&quot;)')"/>
                <xsl:value-of select="$groupHeader"/>
            </xsl:element>
            <div class="level2">
                <xsl:element name="div">
                    <xsl:attribute name="id" select="$id"/>
                    <xsl:attribute name="class" select="'toggle'"/>
                    <!-- create tabel element for group, id needs to be set runtime -->
                    <xsl:element name="table">
                        <xsl:attribute name="class" select="'values'"/>
                        <xsl:choose>
                            <xsl:when test="$groupName='COCT'">
                                <!-- re-use schemaList, GS sort cannot handle unused defintions -->
                                <xsl:attribute name="id" select="'schemaList'"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:attribute name="id" select="concat($groupName,'schemaList')"/>
                            </xsl:otherwise>
                        </xsl:choose>

                        <thead>
                            <tr>
                                <th class="larger" title="Bestandsnaam XML Schema">XML Schema</th>
                                <th class="larger" title="R-MIM bevat de volgende naam en omschrijving">Omschrijving</th>
                                <th class="larger" title="Schema bevat de volgende include(s), die mogelijk zelf ook weer includes bevatten">Includes</th>
                                <th class="larger" title="Schema wordt gebruikt in de volgende interactie(s)">Interactie</th>
                            </tr>
                        </thead>
                        <xsl:for-each select="current-group()">
                            <xsl:variable name="fullDirName" select="document-uri(.)"/>
                            <xsl:variable name="fileName" select="tokenize(document-uri(.), '/')[last()]"/>
                            <xsl:variable name="dirName" select="tokenize(document-uri(.), '/')[last()-1]"/>
                            <tr>
                                <td class="value">
                                    <xsl:element name="a">
                                        <xsl:attribute name="name">
                                            <xsl:value-of select="$fileName"/>
                                        </xsl:attribute>
                                    </xsl:element>
                                    <xsl:element name="a">
                                        <xsl:attribute name="href">
                                            <xsl:value-of select="concat($dirName,'/',$fileName)"/>
                                        </xsl:attribute>
                                        <xsl:value-of select="$fileName"/>
                                    </xsl:element>
                                </td>
                                <td class="value">
                                    <xsl:variable name="fileDescription">
                                        <xsl:call-template name="getDescriptionForSchema">
                                            <xsl:with-param name="schemaFileName" select="$fileName"/>
                                        </xsl:call-template>
                                    </xsl:variable>
                                    <xsl:choose>
                                        <xsl:when test="$fileDescription and not($fileDescription='')">
                                            <!-- START DEBUG INFO -->
                                            <xsl:if test="contains($fileName,'_MT')">
                                                <xsl:variable name="schemaBaseName" select="replace(substring-before($fileName,'.'),'_MT','_RM')"/>
                                                <xsl:variable name="visioLocation" select="document($visioInfoFileNormalized)/*/file[@name=concat($schemaBaseName,'.xml')][1]/@relpath"/>
                                                <xsl:comment> (DEBUG) Visio location: <xsl:value-of select="$visioLocation"/></xsl:comment>
                                            </xsl:if>
                                            <!-- END DEBUG INFO -->
                                            <xsl:value-of select="$fileDescription"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <!-- START DEBUG INFO -->
                                            <xsl:variable name="schemaBaseName" select="replace(substring-before($fileName,'.'),'_MT','_RM')"/>
                                            <xsl:comment> (DEBUG) Visio missing: <xsl:value-of select="concat($schemaBaseName,'.xml')"/>
                                            </xsl:comment>
                                            <!-- END DEBUG INFO -->
                                            <xsl:text>Omschrijving ontbreekt</xsl:text>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </td>
                                <td class="value">
                                    <xsl:variable name="includes" select="document($fullDirName)/xs:schema/xs:include"/>
                                    <xsl:for-each select="$includes">
                                        <xsl:variable name="schemaLocation" select="@schemaLocation"/>
                                        <div>
                                            <xsl:choose>
                                                <xsl:when test="contains($schemaLocation,'coreschemas') or $dirName='coreschemas'">
                                                    <xsl:element name="a">
                                                        <xsl:attribute name="href">
                                                            <xsl:value-of select="concat('intro/coreschemas.html#',tokenize($schemaLocation, '/')[last()])"/>
                                                        </xsl:attribute>
                                                        <xsl:value-of select="$schemaLocation"/>
                                                    </xsl:element>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:element name="a">
                                                        <xsl:attribute name="href">
                                                            <xsl:value-of select="concat('#',$fileName)"/>
                                                        </xsl:attribute>
                                                        <xsl:value-of select="$schemaLocation"/>
                                                    </xsl:element>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </div>
                                    </xsl:for-each>
                                </td>
                                <td class="value">
                                    <xsl:for-each select="document($schemaInfoFileNormalized)//file[@file=$fileName]/used-in[matches(@file,'[A-Z]{4}_IN')]">
                                        <xsl:sort select="@file"/>
                                        <xsl:variable name="currentFile" select="@file"/>
                                        <div>
                                            <xsl:element name="a">
                                                <xsl:attribute name="href">
                                                    <xsl:value-of select="concat('#',$currentFile)"/>
                                                </xsl:attribute>
                                                <xsl:value-of select="$currentFile"/>
                                            </xsl:element>
                                        </div>
                                    </xsl:for-each>
                                </td>
                            </tr>
                        </xsl:for-each>
                    </xsl:element>
                </xsl:element>
            </div>
        </xsl:for-each-group>
    </xsl:template>

    <!-- template for creating list of schematron directory content -->
    <xsl:template name="schematronFileList">
        <xsl:variable name="directory" select="resolve-uri($inputdirSchematron)" as="xs:anyURI"/>
        <xsl:variable name="dir" select="File:new($directory)"/>
        <xsl:variable name="files" select="File:list($dir)"/>
        <table class="values" id="schematronList">
            <thead>
                <tr>
                    <th class="larger">Map/bestand</th>
                    <th class="larger">Omschrijving</th>
                </tr>
            </thead>
            <xsl:for-each select="$files">
                <xsl:variable name="dirName" select="tokenize($inputdirSchematron, '/')[last()]"/>
                <xsl:if test="not(starts-with(.,'.'))">
                    <xsl:variable name="description">
                        <xsl:call-template name="getDescriptionForSchematron">
                            <xsl:with-param name="resource" select="."/>
                        </xsl:call-template>
                    </xsl:variable>
                    <tr>
                        <td class="value">
                            <b>
                                <xsl:element name="a">
                                    <xsl:attribute name="name">
                                        <xsl:value-of select="."/>
                                    </xsl:attribute>
                                </xsl:element>
                                <xsl:element name="a">
                                    <xsl:attribute name="href">
                                        <xsl:value-of select="concat($dirName,'/',.)"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="."/>
                                </xsl:element>
                            </b>
                        </td>
                        <td class="value">
                            <xsl:copy-of select="$description" copy-namespaces="no"/>
                        </td>
                    </tr>
                </xsl:if>
            </xsl:for-each>
        </table>
    </xsl:template>

    <!-- template for creating list of vocab directory content -->
    <xsl:template name="vocabFileList">
        <table class="values" id="vocabList">
            <thead>
                <tr>
                    <th class="larger">Naam</th>
                    <th class="larger">OID</th>
                </tr>
            </thead>
            <xsl:for-each select="collection(iri-to-uri(concat(resolve-uri($inputdirVocab),'?select=', '*.xml;recurse=no')))">
                <xsl:sort select="tokenize(document-uri(.), '/')[last()]"/>
                <xsl:variable name="fullDirName" select="document-uri(.)"/>
                <xsl:variable name="fileName" select="tokenize(document-uri(.), '/')[last()]"/>
                <xsl:variable name="dirName" select="tokenize(document-uri(.), '/')[last()-1]"/>
                <xsl:variable name="fileNameBase" select="substring($fileName,1,string-length($fileName)-4)"/>
                <tr>
                    <td class="value">
                        <xsl:element name="a">
                            <xsl:attribute name="href">
                                <xsl:value-of select="concat($dirName,'/',$fileName)"/>
                            </xsl:attribute>
                            <xsl:variable name="csName" select="normalize-space(document($fullDirName)/hl7:codeSystem/hl7:name)"/>
                            <xsl:choose>
                                <xsl:when test="string-length($csName)>0">
                                    <xsl:value-of select="$csName"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$fileNameBase"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:element>
                    </td>
                    <td class="value">
                        <xsl:variable name="vsOid" select="normalize-space(document($fullDirName)/hl7:codeSystem/hl7:code[1]/@codeSystem)"/>
                        <xsl:choose>
                            <xsl:when test="$vsOid != ''">
                                <xsl:value-of select="$vsOid"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$fileNameBase"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </td>
                </tr>
            </xsl:for-each>
        </table>
        
    </xsl:template>

    <xsl:template name="addAssetsHeader">
        <script src="css/SpryTabbedPanels.js" type="text/javascript"/>
        <link href="css/nictiz.css" type="text/css" rel="stylesheet"/>
        <link href="css/SpryTabbedPanels.css" rel="stylesheet" type="text/css"/>
        <script src="css/SpryURLUtils.js" type="text/javascript"/>
        <script type="text/javascript" src="css/gs_sortable.js"/>
        <script type="text/javascript">
                    function toggle(toggled,toggler) {
                    if (document.getElementById) {
                    var currentStyle = document.getElementById(toggled).style;
                    var togglerStyle = document.getElementById(toggler).style;
                    if (currentStyle.display == "block"){
                    currentStyle.display = "none";
                    togglerStyle.backgroundImage = "url(css/trClosed.gif)";
                    } else {
                    currentStyle.display = "block";
                    togglerStyle.backgroundImage = "url(css/trOpen.gif)";
                    }
                    return false;
                    } else {
                    return true;
                    }
                    }
                </script>
        <script type="text/javascript">
            var TSort_Data = new Array ('wsdlList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('schemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('schematronList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('vocabList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('directoryList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('InteractiesschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('COMTschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('MCAIschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('MCCIschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('MFMIschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('MFMTschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('POORschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('PORXschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('PRMMschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('PRPAschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('PRPMschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('QUMTschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('QUPAschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('QUPCschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('QUQIschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('QURXschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('RCMRschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
            var TSort_Data = new Array ('REPCschemaList', 'h', 's');
            var TSort_Initial = 0;
            var TSort_Classes = new Array ('plain', 'alternate');
            tsRegister();
      </script>
    </xsl:template>

    <xsl:template name="addAssetsBottom">
        <script type="text/javascript">
          // Grabs the values of the URL parameters for the current URL.
          var params = Spry.Utils.getLocationParamsAsObject();
        </script>

        <script type="text/javascript">
           var TabbedPanels2 = new Spry.Widget.TabbedPanels("TabbedPanels2");
        </script>
    </xsl:template>

    <xsl:template name="getDescriptionForSchema">
        <xsl:param name="schemaFileName"/>
        <xsl:choose>
            <xsl:when test="contains($schemaFileName,'_MT')">
                <!-- Message Type logic -->
                <xsl:if test="doc-available($visioInfoFileNormalized)">
                    <xsl:variable name="schemaBaseName">
                        <xsl:variable name="schemaBaseNameTemp" select="substring-before($schemaFileName,'.')"/>
                        <xsl:choose>
                            <xsl:when test="$hmd//file[@name=$schemaBaseNameTemp]">
                                <xsl:value-of select="$hmd//file[@name=$schemaBaseNameTemp]/@rmim"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="replace($schemaBaseNameTemp,'_MT','_RM')"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:variable>
                    <xsl:variable name="visioLocation" select="replace(document($visioInfoFileNormalized)/*/file[@name=concat($schemaBaseName,'.xml')][1]/@relpath,'\\','/')"/>
                    <!--xsl:message>Getting description for <xsl:value-of select="$schemaBaseName"/> from <xsl:value-of select="$visioLocation"/></xsl:message-->
                    <xsl:if test="doc-available($visioLocation)">
                        <xsl:variable name="visioEntryPointName" select="document($visioLocation)//hl7model/pages[1]/page[1]/entryPoint[1]/@name"/>
                        <xsl:variable name="visioEntryPointDescription" select="replace(document($visioLocation)//hl7model/pages[1]/page[1]/entryPoint[1]/notes[1]/text[1],'Property-contextConductionStyle: [A-Z]','')"/>
                        <xsl:choose>
                            <xsl:when test="$visioEntryPointDescription != '' and lower-case($visioEntryPointDescription) != 'description'">
                                <xsl:value-of select="concat($visioEntryPointName,': ',$visioEntryPointDescription)"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$visioEntryPointName"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:if>
                </xsl:if>
            </xsl:when>
            <xsl:when test="contains($schemaFileName,'_IN')">
                <!-- Interaction logic -->
                <xsl:variable name="schemaBaseName" select="substring-before($schemaFileName,'.')"/>
                <xsl:value-of select="concat('Interactieschema: ',if (doc-available($interactionVocabFile)) then doc($interactionVocabFile)/*/hl7:code[@code=$schemaBaseName]/@displayName else ())"/>
            </xsl:when>
            <xsl:when test="$schemaFileName='CDA.xsd'">
                <!-- Interaction logic -->
                <xsl:variable name="schemaBaseName" select="substring-before($schemaFileName,'.')"/>
                <xsl:value-of select="concat('CDA-schema: ',if (doc-available($interactionVocabFile)) then doc($interactionVocabFile)/*/hl7:code[@code=$schemaBaseName]/@displayName else ())"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:message>Unrecognized schema type. Failed to get a description for '<xsl:value-of select="$schemaFileName"/>'</xsl:message>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="getDescriptionForSchematron">
        <xsl:param name="resource"/>
        <xsl:choose>
            <xsl:when test="ends-with($resource,'.sch')">
                <xsl:variable name="schTitle" select="document(concat($inputdirSchematron,'/',.))/*/sch:title[1]"/>
                <xsl:choose>
                    <xsl:when test="string-length($schTitle)">
                        <xsl:value-of select="$schTitle"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>Schematron voor transactie </xsl:text>
                        <xsl:value-of select="substring-before(substring-after($resource,'-'),'.sch')"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="$resource='coreschematron'">
                <xsl:text>Map met basis-schematronbestanden zoals voor wrappers en datatypen</xsl:text>
            </xsl:when>
            <xsl:when test="$resource='APF'">
                <xsl:text>Map met basis-schematronbestanden voor autorisatieprofielen</xsl:text>
            </xsl:when>
            <xsl:when test="$resource='include'">
                <xsl:text>Map met basis-schematron- en vocabulairebestanden voor alle via de </xsl:text>
                <a href="http://decor.nictiz.nl/art-decor">DECOR-methodiek</a>
                <xsl:text> gegenereerde schematron</xsl:text>
            </xsl:when>
            <xsl:when test="$resource='JGZ'">
                <xsl:text>Map met basis-schematronbestanden voor Jeugdgezondheidszorg</xsl:text>
            </xsl:when>
            <xsl:when test="$resource='Mp'">
                <xsl:text>Map met basis-schematronbestanden voor medicatieproces</xsl:text>
            </xsl:when>
            <xsl:when test="$resource='PPF'">
                <xsl:text>Map met basis-schematronbestanden voor patiëntprofielen</xsl:text>
            </xsl:when>
            <xsl:when test="$resource='Sgl'">
                <xsl:text>Map met basis-schematronbestanden voor signaleringen</xsl:text>
            </xsl:when>
            <xsl:when test="$resource='VWI'">
                <xsl:text>Map met basis-schematronbestanden voor de Verwijsindex</xsl:text>
            </xsl:when>
            <xsl:when test="$resource='WDH'">
                <xsl:text>Map met basis-schematronbestanden voor Huisartswaarneemgegevens</xsl:text>
            </xsl:when>
            <xsl:when test="$resource='xslUtils'">
                <xsl:text>Map met conversietools van </xsl:text>
                <a href="http://www.schematron.com">www.schematron.com</a>
                <xsl:text> voor de conversie van Schematron naar XSLT</xsl:text>
            </xsl:when>
            <xsl:when test="ends-with($resource,'-include')">
                <xsl:text>Map met basis-schematronbestanden voor </xsl:text>
                <xsl:value-of select="tokenize($resource,'-')[last()-1]"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>&#160;</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
