@echo off

:: -------------------------------------------
:: --  set defaults                      --
:: --                                       --
:: -------------------------------------------

:: These are used on the commandline
set currentDir=%~d0%~p0
set inputDir=..\..\schemas_codeGen
set outputDir=..\..\schemas_codeGen_flat
set toolCommand=%ProgramFiles%\oxygen\flattenSchema.bat

:: These are used on the command line and must contain a forward slash in path
set jarDir=../lib
set xslDir=.

:: -------------------------------------------
:: --  use input params instead of defaults --
:: --  if given                             --
:: -------------------------------------------

if not (%1)==() set inputDir=%1
if not (%2)==() set outputDir=%2
if not (%3)==() set toolCommand=%3
::if not (%3)==() set jarDir=%3
::if not (%4)==() set xslDir=%4

:: Workaround for bug in Oxygens ./flattenSchema script, which will be fixed in Oxygen 1.6
:: 26 sep. 2014, 16:43 Oxygen XML Editor Support <support@oxygenxml.com>:
:: Hello Alexander,
:: Thank you for letting us know about this and thank you very much for proving the samples 
:: and full details to reproduce this. The command line version of the flatten schema should 
:: provide the same results as the GUI one. However, in your case a bug is triggered for the 
:: command line version due to the relative path used for the output directory.
:: Based on your feedback a developer has already analyzed and resolved this issue in the 
:: current development stream. The bugfix will be included in v16.1 (to be released soon).
:: Meanwhile, a simple solution for this problem is to use absolute paths for the output 
:: directory. You can use in your bash scrip this simplistic function that resolves the relative 
:: paths to absolute ones.
cd %inputDir%
set inputDir=%CD%
cd %currentDir%
cd %outputDir%
set outputDir=%CD%
cd %currentDir%

echo.Input directory                 = [%inputdir%]
echo.Output directory                = [%outputDir%]
echo.Oxygen flattenSchema command    = [%toolCommand%]
::echo.Java jar directory              = [%jarDir%]
::echo.xsl directory                   = [%xslDir%]

:: -------------------------------------------
:: --  check input and output dirs          --
:: --                                       --
:: -------------------------------------------

if not exist "%toolCommand%" echo.ERROR The Oxygen tool [%toolCommand%] does not exist! Cannot proceed. & pause & exit /B

if not exist "%inputdir%" echo.ERROR The input directory [%inputDir%] does not exist or is empty! Cannot proceed. & pause & exit /B

if exist %outputDir% echo.WARNING The output directory [%outputDir%] already exists! Please check if this does not pollute your results! You may need to empty the output directory: [%outputDir%] first.

if not exist "%outputDir%" (
    echo.
    echo Creating output directory: "%outputDir%" ...
    echo -----------------------
    echo.
    mkdir "%outputDir%"
 ) else (
    echo.
    echo Removing html and graphics contents of output directory: "%outputDir%" ...
    echo -----------------------
    echo.
    del /Q "%outputDir%\*.*"
 )
 
:: -------------------------------------------
:: --  generate output                      --
:: --                                       --
:: -------------------------------------------

::echo.Building xmlschemainfo.xml...
::echo.
::cmd /c ..\resolveIncludes\buildXmlSchemaInfoForDir.bat

echo.
echo.Transforming interaction schemas...
for %%F in (%inputDir%\*_IN*.xsd) do (
    echo   Processing %%~nF%%~xF...
    ::java -jar %jarDir%/saxon-9/saxon9.jar -s:%%F -xsl:%xslDir%/flattenSchemas.xsl -o:%outputDir%/%%~nF%%~xF
    %toolCommand% -in:%%F -outDir:%outputDir% -flattenImports:true
)
