#!/bin/sh

# -----------------------------------------
# --  set defaults                       --
# -----------------------------------------

# These are used on the command line
export inputDir=../../schemas_codeGen
export outputDir=../../schemas_codeGen_flat
export toolCommand=/Applications/oxygen/flattenSchemaMac.sh

# These are used on the command line and must contain a forward slash in path
#export jarDir=../lib
#export xslDir=.

# Workaround for bug in Oxygens ./flattenSchema script, which will be fixed in Oxygen 1.6
# 26 sep. 2014, 16:43 Oxygen XML Editor Support <support@oxygenxml.com>:
# Hello Alexander,
# Thank you for letting us know about this and thank you very much for proving the samples 
# and full details to reproduce this. The command line version of the flatten schema should 
# provide the same results as the GUI one. However, in your case a bug is triggered for the 
# command line version due to the relative path used for the output directory.
# Based on your feedback a developer has already analyzed and resolved this issue in the 
# current development stream. The bugfix will be included in v16.1 (to be released soon).
# Meanwhile, a simple solution for this problem is to use absolute paths for the output 
# directory. You can use in your bash scrip this simplistic function that resolves the relative 
# paths to absolute ones.
realpath() {
    OLDPWD=$PWD 
    cd "$1" 
    REALPATH="$PWD" 
    cd "$OLDPWD" 
    echo "$REALPATH" 
} 

# -------------------------------------------
# --  use input params instead of defaults --
# --  if given                             --
# -------------------------------------------

if [ ! $1 = '' ]; then export inputDir=$1; fi
if [ ! $2 = '' ]; then export outputDir=$2; fi
if [ ! $3 = '' ]; then export toolCommand=$3; fi
#if [ ! $3 = '' ]; then export jarDir=$3; fi
#if [ ! $4 = '' ]; then export xslDir=$4; fi

export inputDir=`realpath ${inputDir}`
export outputDir=`realpath ${outputDir}`

echo "Input directory                 = ${inputDir}"
echo "Output directory                = ${outputDir}"
echo "Oxygen flattenSchema command    = ${toolCommand}"
#echo "Java jar path                   = $jarDir"
#echo "XSL path                        = $xslDir"

# -------------------------------------------
# --  check input and output dirs          --
# --                                       --
# -------------------------------------------

if [ ! -e "${toolCommand}" ]; then
    echo ERROR The Oxygen tool \'${toolCommand}\' does not exist!
    exit
fi

if [ ! -e "${inputDir}" ]; then 
    echo ERROR The input directory \'${inputDir}\' does not exist or is empty!
    exit
fi

if [ "${inputDir}" = "${outputDir}" ]; then
    echo ERROR The input directory must not be equal to the output directory!
    exit
fi

if [ ! -e "${outputDir}" ]; then 
    echo "\nCreating output directory ${outputDir}..."
    echo "-----------------------\n"
    mkdir "${outputDir}"
else
    echo "\nRemoving contents of output directory ${outputDir}..."
    echo "-----------------------\n"
    rm ${outputDir}/*.*
fi

# -------------------------------------------
# --  generate output                      --
# --                                       --
# -------------------------------------------

#echo "Building xmlschemainfo.xml..."
#echo ""
#../resolveIncludes/buildXmlSchemaInfoForDir.sh

echo Transforming interaction schemas...
for file in `ls ${inputDir}/*_IN*.xsd` ; do
    echo "    Processing `basename $file`..."    
#    java -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/flattenSchemas.xsl -o:${outputDir}/`basename $file`
     ${toolCommand} -in:${file} -outDir:${outputDir} -flattenImports:true
done