#!/bin/sh

# -----------------------------------------
# --  set defaults                       --
# -----------------------------------------

export inputDir=./mep
export outputDir=../../schemas

# The in- and outputPath variables are used in the stylesheets 
export inputPath=./mep/
export outputPath=../../schemas/

export jarDir=../lib/saxon-9
export xslDir=.

# -------------------------------------------
# --  use input params instead of defaults --
# --  if given                             --
# -------------------------------------------

if [ ! $1 = '' ]; then export inputDir=$1; fi
if [ ! $2 = '' ]; then export outputDir=$2; fi
if [ ! $3 = '' ]; then export inputPath=$3; fi
if [ ! $4 = '' ]; then export outputPath=$4; fi
if [ ! $5 = '' ]; then export jarDir=$5; fi
if [ ! $6 = '' ]; then export xslDir=$6; fi
if [ ! $7 = '' ]; then export inputFile=$7; else export inputFile=''; fi


echo "Input directory                 = $inputDir"
echo "Output directory                = $outputDir"
echo "Input directory for Stylesheet  = $inputPath"
echo "Output directory for Stylesheet = $outputPath"
echo "Java jar path                   = $jarDir"
echo "XSL path                        = $xslDir"
echo "Input file                      = $inputFile"

# -------------------------------------------
# --  check input and output dirs          --
# --                                       --
# -------------------------------------------

if [ ! "$inputFile" = '' ]; then
    if [ ! -e "$inputFile" ]; then
        echo ERROR The input file \'${inputFile}\' does not exist!
        exit
    fi
fi

if [ ! -e "$inputDir" ]; then 
    echo ERROR The input directory \'${inputDir}\' does not exist or is empty!
    exit
fi

if [ "$inputDir" = "$outputDir" ]; then
    echo ERROR The input directory must not be equal to the output directory!
    exit
fi

if [ ! -e "$outputDir" ]; then mkdir "$outputDir"; fi

if [ ! -e "$outputDir" ]; then 
    echo "\nCreating output directory $outputDir..."
    echo "-----------------------\n"
    mkdir "$outputDir"
fi

# -------------------------------------------
# --  copy input files to output dir       --
# --  and generate the interactions        --
# -------------------------------------------

echo
if [ ! ${inputFile} = '' ]; then
    echo Transforming input file ${inputFile}...
    java -jar ${jarDir}/saxon9.jar -s:$inputFile -xsl:${xslDir}/MakeInteraction.xsl outputDir=${outputPath}
else
    echo Transforming input files...
    for file in `ls ${inputDir}/*_mep.xml`
        do java -jar ${jarDir}/saxon9.jar -s:$file -xsl:${xslDir}/MakeInteraction.xsl outputDir=${outputPath}
    done
fi
echo
echo Done with this batch file...

