@echo off

:: -------------------------------------------
:: --  set defaults                      --
:: --                                       --
:: -------------------------------------------

:: These are used on the commandline
set inputDir=..\..\schemas
set outputDir=..\..\schemas\temp

:: These are used on the command line and must contain a forward slash in path
set jarDir=../lib
set xslDir=.

:: -------------------------------------------
:: --  use input params instead of defaults --
:: --  if given                             --
:: -------------------------------------------

if not (%1)==() set inputDir=%1
if not (%2)==() set outputDir=%2
if not (%3)==() set jarDir=%3
if not (%4)==() set xslDir=%4

echo.Input directory                 = [%inputdir%]
echo.Output directory                = [%outputDir%]
echo.Java jar directory              = [%jarDir%]
echo.xsl directory                   = [%xslDir%]

:: -------------------------------------------
:: --  check input and output dirs          --
:: --                                       --
:: -------------------------------------------

if not exist "%inputdir%" echo.ERROR The input directory [%inputDir%] does not exist or is empty! Cannot proceed. & pause & exit /B

if exist %outputDir% echo.WARNING The output directory [%outputDir%] already exists! Please check if this does not pollute your results! You may need to empty the output directory: [%outputDir%] first.

if not exist "%outputDir%" (
    echo.
    echo Creating output directory: "%outputDir%" ...
    echo -----------------------
    echo.
    mkdir "%outputDir%"
 ) else (
    echo.
    echo Removing html and graphics contents of output directory: "%outputDir%" ...
    echo -----------------------
    echo.
    del /Q "%outputDir%\*.*"
 )
 
:: -------------------------------------------
:: --  generate output                      --
:: --                                       --
:: -------------------------------------------

echo.Transforming Interaction schemas...
for %%F in (%inputDir%\*.xsd) do java -jar %jarDir%/saxon-9/saxon9.jar -s:%%F -xsl:%xslDir%/schemaCleanup.xsl -o:%outputDir%/%%~nF%%~xF

echo.Removing original schemas...
del /Q %inputDir%\*.xsd

echo.Moving result schemas into location of original schemas...
move /Y %outputDir%\*.xsd %inputDir%\

echo.Removing temporary output directory...
del /Q %outputDir%
