#!/bin/sh

# -----------------------------------------
# --  set defaults                       --
# -----------------------------------------

# These are used on the command line
export inputDir=../../schemas
export outputDir=../../schemas/temp

# These are used on the command line and must contain a forward slash in path
export jarDir=../lib
export xslDir=.

# -------------------------------------------
# --  use input params instead of defaults --
# --  if given                             --
# -------------------------------------------

if [ ! $1 = '' ]; then export inputDir=$1; fi
if [ ! $2 = '' ]; then export outputDir=$2; fi
if [ ! $3 = '' ]; then export jarDir=$5; fi
if [ ! $4 = '' ]; then export xslDir=$6; fi

echo "Input directory                 = ${inputDir}"
echo "Output directory                = ${outputDir}"
echo "Java jar path                   = $jarDir"
echo "XSL path                        = $xslDir"

# -------------------------------------------
# --  check input and output dirs          --
# --                                       --
# -------------------------------------------

if [ ! -e "${inputDir}" ]; then 
    echo ERROR The input directory \'${inputDir}\' does not exist or is empty!
    exit
fi

if [ "${inputDir}" = "${outputDir}" ]; then
    echo ERROR The input directory must not be equal to the output directory!
    exit
fi

if [ ! -e "${outputDir}" ]; then 
    echo "\nCreating output directory ${outputDir}..."
    echo "-----------------------\n"
    mkdir "${outputDir}"
else
    echo "\nRemoving contents of output directory ${outputDir}..."
    echo "-----------------------\n"
    rm ${outputDir}/*.*
fi

# -------------------------------------------
# --  generate output                      --
# --                                       --
# -------------------------------------------

echo Transforming schemas...
for file in `ls ${inputDir}/*.xsd`
    do java -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/schemaCleanup.xsl -o:${outputDir}/`basename $file`
done

echo Removing original schemas...
rm ${inputDir}/*.xsd

echo Moving result schemas into location of original schemas...
mv ${outputDir}/*.xsd ${inputDir}/

echo Removing temporary output directory...
rm -r ${outputDir}
