#!/bin/sh

# -----------------------------------------
# --  set defaults                       --
# -----------------------------------------

# These are used on the command line
export inputDir=../../schemas
export outputDir=../../schemas_codeGen

# These are used on the command line and must contain a forward slash in path
export jarDir=../lib
export xslDir=.

# -------------------------------------------
# --  use input params instead of defaults --
# --  if given                             --
# -------------------------------------------

if [ ! $1 = '' ]; then export inputDir=$1; fi
if [ ! $2 = '' ]; then export outputDir=$2; fi
if [ ! $3 = '' ]; then export jarDir=$5; fi
if [ ! $4 = '' ]; then export xslDir=$6; fi

echo "Input directory                 = ${inputDir}"
echo "Output directory                = ${outputDir}"
echo "Java jar path                   = $jarDir"
echo "XSL path                        = $xslDir"

# -------------------------------------------
# --  check input and output dirs          --
# --                                       --
# -------------------------------------------

if [ "${inputDir}" = "${outputDir}" ]; then
    echo ERROR The input directory must not be equal to the output directory!
    exit
fi

if [ ! -e "${outputDir}" ]; then 
    echo "\nCreating output directory ${outputDir}..."
    echo "-----------------------\n"
    mkdir "${outputDir}"
else
    echo "\nRemoving contents of output directory ${outputDir}..."
    echo "-----------------------\n"
    rm ${outputDir}/*.*
fi

# -------------------------------------------
# --  generate output                      --
# --                                       --
# -------------------------------------------

echo "Transforming interaction schemas..."
for file in `ls ${inputDir}/*.xsd | grep -v COCT_MT | grep -v POCP_MT`; do
    echo "  Processing `basename $file`..."
    java -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/makeSchemaCodeGen.xsl -o:${outputDir}/`basename $file`
done

echo ""
echo "Copying certain files overwriting any previous results..."
if ls ${inputDir}/COCT_MT*.xsd &> /dev/null; then
    echo "    Copying COCT_MT*.xsd CMETs..."
    cp -p ${inputDir}/COCT_MT*.xsd ${outputDir}
fi
if ls ${inputDir}/POCP_MT*.xsd &> /dev/null; then
    echo "    Copying POCP_MT*.xsd CMETs..."
    cp -p ${inputDir}/POCP_MT*.xsd ${outputDir}
fi
if [ -e "${inputDir}/MCCI_IN200100.xsd" ]; then
    echo "    Copying MCCI_IN200101.xsd batch send wrapper..."
    cp -p ${inputDir}/MCCI_IN200100.xsd ${outputDir}
fi
if [ -e "${inputDir}/MCCI_IN200101.xsd" ]; then
    echo "    Copying MCCI_IN200101.xsd batch response wrapper..."
    cp -p ${inputDir}/MCCI_IN200101.xsd ${outputDir}
fi
