<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:hl7="urn:hl7-org:v3"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl" exclude-result-prefixes="#all">
    <xd:doc scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Created on:</xd:b> Jul 7, 2011</xd:p>
            <xd:p><xd:b>Author:</xd:b> gboers</xd:p>
            <xd:p><xd:b>Purpose:</xd:b> stylesheet for generating schemas for the ZIM. <xd:ul>
                <xd:li>Remove includes of payload message type schemas</xd:li>
                <xd:li>Convert payload references to xs:any</xd:li>
            </xd:ul>
                <xd:pre>Note: use only with interactions schemas in the schemas_codeGen folder. This stylesheet uses the configuration file anyTypesListLSP.xml.</xd:pre></xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:output method="xml" indent="yes"/>
    <xsl:strip-space elements="*"/>
    <!-- copy pi and comments -->
    <xsl:template match="processing-instruction()|comment()" mode="#all">
        <xsl:copy-of select="."/>
    </xsl:template>
    <xsl:template match="@*|*">
        <xsl:variable name="schemaName" select="tokenize(@schemaLocation,'/')[last()]"/>
        <xsl:variable name="elementName" select="@name"/>
        <xsl:choose>
            <!-- Indien er een include is van een schema dat in anyTypesListLSP.xml voorkomt
                wordt deze vervangen door een commentaarregel-->
            <xsl:when test="self::xs:include and document('anyTypesListLSP.xml')/*/payload[@schemaName=$schemaName]">
                <xsl:comment>Include <xsl:value-of select="$schemaName"/> removed to exclude from XML Schema validation</xsl:comment>
            </xsl:when>
            <!-- Indien er een choice is waarin een naam in anyTypesListLSP.xml voorkomt -->
            <xsl:when test="self::xs:choice">
                <xsl:variable name="containsMedicalContent">
                    <xsl:for-each select="xs:element">
                        <xsl:variable name="elementChoiceName" select="@name"/>
                        <xsl:if test="document('anyTypesListLSP.xml')/*/payload[@payloadName=$elementChoiceName]">
                            <xsl:text>true</xsl:text>
                        </xsl:if>
                    </xsl:for-each>
                </xsl:variable>
                <xsl:choose>
                    <xsl:when test="starts-with($containsMedicalContent,'true')">
                        <xsl:element name="xs:choice">
                            <xsl:for-each select="@*">
                                <xsl:copy-of select="."/>
                            </xsl:for-each>
                            <xsl:comment>Choice elements replaced with xs:any to exclude from XML Schema validation</xsl:comment>
                            <xsl:element name="xs:any">
                                <xsl:attribute name="namespace">
                                    <xsl:value-of select="'##any'"/>
                                </xsl:attribute>
                                <xsl:attribute name="processContents">
                                    <xsl:value-of select="'skip'"/>
                                </xsl:attribute>
                            </xsl:element>
                        </xsl:element>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:copy>
                            <!-- alle andere elementen en attributen worden gewoon gekopieerd -->
                            <xsl:apply-templates select="@*|node()"/>
                        </xsl:copy>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <!-- Indien er een element is met een naam in anyTypesListLSP.xml voorkomt
                wordt deze vervangen door xs:any-->
            <xsl:when test="self::xs:element and document('anyTypesListLSP.xml')/*/payload[@payloadName=$elementName]">
                <xsl:comment>Element <xsl:value-of select="$elementName"/> replaced with xs:any to exclude from XML Schema validation</xsl:comment>
                <xsl:element name="xs:any">
                    <xsl:attribute name="namespace">
                        <xsl:value-of select="'##any'"/>
                    </xsl:attribute>
                    <xsl:attribute name="processContents">
                        <xsl:value-of select="'skip'"/>
                    </xsl:attribute>
                </xsl:element>
            </xsl:when>
            <xsl:otherwise>
                <xsl:copy>
                    <!-- alle andere elementen en attributen worden gewoon gekopieerd -->
                    <xsl:apply-templates select="@*|node()"/>
                </xsl:copy>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
