<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" xmlns:hl7="urn:hl7-org:v3" exclude-result-prefixes="#all"
    xmlns:File="java:java.io.File" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl" xmlns:xs="http://www.w3.org/2001/XMLSchema">
    <xd:doc scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Created on:</xd:b> Jul 7, 2011</xd:p>
            <xd:p><xd:b>Author:</xd:b> gboers</xd:p>
            <xd:p><xd:b>Param:</xd:b> batchType - type of batch file to create. 'sh' for Unix, 'bat' for Windows</xd:p>
            <xd:p><xd:b>Param:</xd:b> inputDir - normally ../../schemas_codeGen or ..\..\schemas_codeGen, the directory to copy the includes from, without a trailing (back)slash</xd:p>
            <xd:p><xd:b>Param:</xd:b> outputDir - normally ../../schemas_codeGen_LSP or ..\..\schemas_codeGen_LSP, the directory to copy the includes to, and where the interaction schemas should already be, without a trailing (back)slash</xd:p>
            <xd:p><xd:b>Purpose:</xd:b> read all interaction XML Schemas from the outputDir that have been transformed in a previous step (see readme.txt in this folder) and follow the includes recursively. The list of includes that is built this way is then written into a text file that may be executed as a batch script as a post-processing step after this transformation finishes.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:output method="text"/>
    <!-- sh or bat -->
    <xsl:param name="batchType"/>
    <!-- Directory to read message types from, normally schemas_codeGen -->
    <xsl:param name="inputDir" required="yes"/>
    <!-- Directory to write message types to, and where the converted interactions files should already be -->
    <xsl:param name="outputDir"/>
    <!-- Generated file that contains all includes per file  -->
    <xsl:param name="xmlschemainfo" select="'../resolveIncludes/xmlschemainfo.xml'"/>
    <!-- Convert backslashes to forward slashes -->
    <xsl:variable name="inputdirectory" select="replace(translate($inputDir,'\\','/'),'/$','')"/>
    <!-- Convert backslashes to forward slashes -->
    <xsl:variable name="outputdirectory" select="replace(translate($outputDir,'\\','/'),'/$','')"/>
    
    <xsl:variable name="includeList">
        <xsl:call-template name="checkParameters"/>
        <xsl:variable name="tempList">
            <includes>
                <xsl:for-each select="document($xmlschemainfo)/*/file[matches(@file,'^[A-Z]{4}_IN.*xsd$')]/uses">
                    <xsl:variable name="docUri" select="@full"/>
                    <xsl:variable name="docFileName" select="@file"/>
                    <xsl:if test="not(contains($docUri,'coreschemas'))">
                        <include schemaLocation="{$docUri}" schemaFileName="{$docFileName}"/>
                    </xsl:if>
                </xsl:for-each>
            </includes>
        </xsl:variable>
        <includes>
            <xsl:copy-of select="$tempList/*/include[not(@schemaFileName=preceding-sibling::include/@schemaFileName)]"/>
        </includes>
    </xsl:variable>
        
    <xsl:template match="/">
        <xsl:call-template name="checkParameters"/>
        <xsl:choose>
            <xsl:when test="$batchType='sh'">
                <xsl:text>#!/bin/sh&#xa;</xsl:text>
            </xsl:when>
            <xsl:when test="$batchType='bat'">
                <xsl:text>@echo off&#xd;&#xa;</xsl:text>
            </xsl:when>
        </xsl:choose>
        <xsl:for-each select="$includeList/*/include">
            <xsl:sort select="@schemaFileName"/>
            <xsl:choose>
                <xsl:when test="$batchType='sh'">
                    <xsl:value-of select="concat('cp -p ',$inputdirectory,'/',@schemaFileName,' ',$outputdirectory,'/&#xa;')"/>
                </xsl:when>
                <xsl:when test="$batchType='bat'">
                    <xsl:value-of select="concat('copy /y ',translate($inputdirectory,'/','\\'),'\',@schemaFileName,' ',translate($outputdirectory,'/','\\'),'\&#xd;&#xa;')"/>
                </xsl:when>
            </xsl:choose>
        </xsl:for-each>
    </xsl:template>
    
    <!-- Check input parameters to this transformation -->
    <xsl:template name="checkParameters">
        <xsl:variable name="errorMessage">
            <xsl:if test="not($batchType='sh' or $batchType='bat')">
                <xsl:value-of select="concat('- Parameter batchType should be &quot;sh&quot; or &quot;bat&quot;. Found &quot;',$batchType,'&quot;&#xa;')"/>
            </xsl:if>
            <xsl:if test="$inputDir=''">
                <xsl:value-of select="'- Parameter inputDir is empty&#xa;'"/>
            </xsl:if>
            <xsl:if test="ends-with($inputdirectory,'/')">
                <xsl:value-of select="concat('- Parameter inputDir should not have a trailing (back)slash. Found &quot;',$inputDir,'&quot;&#xa;')"/>
            </xsl:if>
            <xsl:if test="ends-with($outputdirectory,'/')">
                <xsl:value-of select="concat('- Parameter outputDir should not have a trailing (back)slash. Found &quot;',$outputDir,'&quot;&#xa;')"/>
            </xsl:if>
        </xsl:variable>
        <xsl:if test="$errorMessage!=''">
            <xsl:message terminate="yes" select="$errorMessage"/>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>
