@echo off

:: -------------------------------------------
:: --  set defaults                         --
:: --                                       --
:: -------------------------------------------

:: These are used on the commandline
set inputDir=../../schemas_codeGen
set outputDir=../../schemas_codeGen_LSP

:: These are used on the command line and must contain a forward slash in path
set jarDir=../lib
set xslDir=.

:: -------------------------------------------
:: --  use input params instead of defaults --
:: --  if given                             --
:: -------------------------------------------

if not (%1)==() set inputDir=%1
if not (%2)==() set outputDir=%2
if not (%3)==() set jarDir=%3
if not (%4)==() set xslDir=%4

echo.Input directory                 = [%inputdir%]
echo.Output directory                = [%outputDir%]
echo.Java jar directory              = [%jarDir%]
echo.xsl directory                   = [%xslDir%]

:: -------------------------------------------
:: --  check input and output dirs          --
:: --                                       --
:: -------------------------------------------

if "%inputDir%" == "%outputDir%" (
    echo.ERROR The input directory must not be equal to the output directory!
    exit
)

if not exist "%outputDir%" (
    echo.
    echo Creating output directory: "%outputDir%" ...
    echo -----------------------
    echo.
    mkdir "%outputDir%"
 ) else (
    echo.
    echo Removing contents of output directory: "%outputDir%" ...
    echo -----------------------
    echo.
    del /Q "%outputDir%\*.*"
 )
 
:: -------------------------------------------
:: --  generate output                      --
:: --                                       --
:: -------------------------------------------

set xmlschemainfo=../resolveIncludes/xmlschemainfo.xml
echo.Building list of includes/imports per XML Schema for %inputDir%...
echo.
cmd /c ..\resolveIncludes\buildXmlSchemaInfoForDir.bat %inputDir% %xmlschemainfo%

echo.
echo.Transforming interaction schemas, replacing payload with xs:any if necessary...
for %%F in (%inputDir%\*_IN*.xsd) do (
    echo   Processing %%~nF%%~xF...
    java -jar %jarDir%/saxon-9/saxon9.jar -s:%%F -xsl:%xslDir%/makeSchemaCodeGenLSP-interaction.xsl -o:%outputDir%/%%~nF%%~xF
)

echo.
echo.Creating script schemaset_LSP.sh that copies all includes based on includes from %inputDir% to %outputDir%...
java -jar %jarDir%/saxon-9/saxon9.jar -s:anyTypesListLSP.xml -xsl:%xslDir%/makeSchemaCodeGenLSP-script-1.xsl -o:schemaset_LSP.bat batchType=bat inputDir=%inputDir% outputDir=%outputDir% xmlschemainfo=%xmlschemainfo%

echo.
echo.Executing script...
CALL schemaset_LSP.bat

set xmlschemainfo=../resolveIncludes/xmlschemainfo-2.xml
echo.
echo.Building list of includes per XML Schema for %outputDir%...
echo.
cmd /c ..\resolveIncludes\buildXmlSchemaInfoForDir.bat %outputDir% %xmlschemainfo%

echo.
echo.Creating script schemaset_LSP-2.bat that deletes all superfluous files from %outputDir% based on new includes list...
java -jar %jarDir%/saxon-9/saxon9.jar -s:anyTypesListLSP.xml -xsl:%xslDir%/makeSchemaCodeGenLSP-script-2.xsl -o:schemaset_LSP-2.bat batchType=bat workingDir=%outputDir% xmlschemainfo=%xmlschemainfo%

echo.
echo.Executing script...
CALL schemaset_LSP-2.bat
