#!/bin/sh

# -----------------------------------------
# --  set defaults                       --
# -----------------------------------------

# These are used on the command line
export inputDir=../../schemas_codeGen
export outputDir=../../schemas_codeGen_LSP

# These are used on the command line and must contain a forward slash in path
export jarDir=../lib
export xslDir=.

# -------------------------------------------
# --  use input params instead of defaults --
# --  if given                             --
# -------------------------------------------

if [ ! $1 = '' ]; then export inputDir=$1; fi
if [ ! $2 = '' ]; then export outputDir=$2; fi
if [ ! $3 = '' ]; then export jarDir=$5; fi
if [ ! $4 = '' ]; then export xslDir=$6; fi

echo "Input directory                 = ${inputDir}"
echo "Output directory                = ${outputDir}"
echo "Java jar path                   = $jarDir"
echo "XSL path                        = $xslDir"

# -------------------------------------------
# --  check input and output dirs          --
# --                                       --
# -------------------------------------------

if [ "${inputDir}" = "${outputDir}" ]; then
    echo ERROR The input directory must not be equal to the output directory!
    exit
fi

if [ ! -e "${outputDir}" ]; then 
    echo "\nCreating output directory ${outputDir}..."
    echo "-----------------------\n"
    mkdir "${outputDir}"
else
    echo "\nRemoving contents of output directory ${outputDir}..."
    echo "-----------------------\n"
    rm ${outputDir}/*.*
fi

# -------------------------------------------
# --  generate output                      --
# --                                       --
# -------------------------------------------

export xmlschemainfo=../resolveIncludes/xmlschemainfo.xml
echo "Building list of includes/imports per XML Schema for ${inputDir}..."
echo ""
../resolveIncludes/buildXmlSchemaInfoForDir.sh ${inputDir} ${xmlschemainfo}

echo ""
echo "Transforming interaction schemas, replacing payload with xs:any if necessary..."
for file in `ls ${inputDir}/*_IN*.xsd` ; do
    echo "    Processing `basename $file`..."
    java -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/makeSchemaCodeGenLSP-interaction.xsl -o:${outputDir}/`basename $file`
done

echo ""
echo "Creating script schemaset_LSP.sh that copies all includes based on includes from ${inputDir} to ${outputDir}..."
java -jar ${jarDir}/saxon-9/saxon9.jar -s:anyTypesListLSP.xml -xsl:${xslDir}/makeSchemaCodeGenLSP-script-1.xsl -o:schemaset_LSP.sh batchType=sh inputDir=${inputDir} outputDir=${outputDir} xmlschemainfo=${xmlschemainfo}

echo "    Making script executable..."
chmod +x ./schemaset_LSP.sh

echo ""
echo "Executing script..."
./schemaset_LSP.sh

export xmlschemainfo=../resolveIncludes/xmlschemainfo-`basename ${outputDir}`.xml
echo ""
echo "Building list of includes per XML Schema for ${outputDir}..."
echo ""
../resolveIncludes/buildXmlSchemaInfoForDir.sh ${outputDir} ${xmlschemainfo}

echo ""
echo "Creating script schemaset_LSP-2.sh that deletes all superfluous files from ${outputDir} based on new includes list..."
java -jar ${jarDir}/saxon-9/saxon9.jar -s:anyTypesListLSP.xml -xsl:${xslDir}/makeSchemaCodeGenLSP-script-2.xsl -o:schemaset_LSP-2.sh batchType=sh workingDir=${outputDir} xmlschemainfo=${xmlschemainfo}

echo "    Making script executable..."
chmod +x ./schemaset_LSP-2.sh

echo ""
echo "Executing script..."
./schemaset_LSP-2.sh

