@echo off
set currdir=%CD%
set logfile=$currdir/makeAll.log

:: -----------------------------------------
:: --  set defaults                       --
:: -----------------------------------------

:: These are used on the command line
set inputDir=../../schematron
set outputDir=%inputDir%_xslt

:: These are used on the command line and must contain a forward slash in path
set jarDir=../lib
set xslDir=../../schematron/xslUtils/iso-schematron-xslt2

:: -------------------------------------------
:: --  use input params instead of defaults --
:: --  if given                             --
:: -------------------------------------------

if not (%1)==() set inputDir=%1
if not (%2)==() set outputDir=%2
if not (%3)==() set jarDir=%3
if not (%4)==() set xslDir=%4

echo.Input directory                 = [%inputdir%]
echo.Output directory                = [%outputDir%]
echo.Java jar directory              = [%jarDir%]
echo.xsl directory                   = [%xslDir%]

:: -------------------------------------------
:: --  check input and output dirs          --
:: --                                       --
:: -------------------------------------------

if not exist "%inputdir%" echo.ERROR The input directory [%inputDir%] does not exist or is empty! Cannot proceed. & pause & exit /B

if "%inputDir%" == "%outputDir%" echo.ERROR The input directory must not be equal to the output directory! & pause & exit /B

if not exist "%outputDir%" (
    echo.
    echo Creating output directory: "%outputDir%" ...
    echo -----------------------
    echo.
    mkdir "%outputDir%"
) else (
    echo.
    echo Removing contents of output directory: "%outputDir%" ...
    echo -----------------------
    echo.
    del /Q "%outputDir%\*.*"
)

:: ------------------------------------------------------
:: --                                                  --
:: --  generate the xslts                              --
:: --  note: -Xmx2048m is used for the biggest SCHs... --
:: ------------------------------------------------------


echo.Transforming input files to XSLT - phase 1...
for %%F in (%inputDir%\*.sch) do (
    echo   Transforming phase 1 - %%F
    java -Xmx2048m -jar %jarDir%/saxon-9/saxon9.jar -o %outputDir%/%%~nF.t1 "%%F" %xslDir%/iso_dsdl_include.xsl allow-foreign=true
)

echo.Transforming input files to XSLT - phase 2...
for %%F in (%outputDir%\*.t1) do (
    echo   Transforming phase 2 - %%F
    java -Xmx2048m -jar %jarDir%/saxon-9/saxon9.jar -o %outputDir%/%%~nF.t2 "%%F" %xslDir%/iso_abstract_expand.xsl allow-foreign=true
)

echo.Transforming input files to XSLT - phase 3...
for %%F in (%outputDir%\*.t2) do (
    echo   Transforming phase 3 - %%F
    java -Xmx2048m -jar %jarDir%/saxon-9/saxon9.jar -o %outputDir%/%%~nF.xsl "%%F" %xslDir%/iso_schematron_message_xslt2.xsl allow-foreign=true
)

echo.Removing temporary files ...
del "%outputDir%\*.t1"
del "%outputDir%\*.t2"

cd %currdir%
