#!/bin/sh
export currdir=`pwd`
export logfile=$currdir/makeAll.log

# -----------------------------------------------
# --  use input params instead or set defaults --
# --                                           --
# -----------------------------------------------

if [ ! $1 = '' ]; then 
    export inputDir=$1; 
else 
    export inputDir=../../schematron
fi
if [ ! $2 = '' ]; then 
    export outputDir=$2; 
else
    export outputDir=${inputDir}_xslt
fi
if [ ! $5 = '' ]; then 
    export jarDir=$5; 
else 
    export jarDir=../lib
fi
if [ ! $6 = '' ]; then 
    export xslDir=$6; 
else
    export xslDir=../../schematron/xslUtils/iso-schematron-xslt2
fi

echo "Input directory                 = ${inputDir}"
echo "Output directory                = ${outputDir}"
echo "Java jar path                   = $jarDir"
echo "XSL path                        = $xslDir"

# -------------------------------------------
# --  check input and output dirs          --
# --                                       --
# -------------------------------------------

if [ ! -e "${inputDir}" ]; then 
    echo ERROR The input directory \'${inputDir}\' does not exist or is empty!
    exit
fi

if [ "${inputDir}" = "${outputDir}" ]; then
    echo ERROR The input directory must not be equal to the output directory!
    exit
fi

if [ ! -e "${outputDir}" ]; then 
    echo "\nCreating output directory ${outputDir}..."
    echo "-----------------------\n"
    mkdir "${outputDir}"
else
    echo "\nRemoving contents of output directory ${outputDir}..."
    echo "-----------------------\n"
    rm  ${outputDir}/*.*
fi

# ------------------------------------------------------
# --                                                  --
# --  generate the xslts                              --
# --  note: -Xmx2048m is used for the biggest SCHs... --
# ------------------------------------------------------

echo
echo Transforming input files to XSLT - phase 1...
for file in `ls ${inputDir}/*.sch` 
do 
    echo "   Transforming phase 1 `basename $file`" ;
    java -Xmx2048m -jar ${jarDir}/saxon-9/saxon9.jar -o ${outputDir}/`basename $file`.t1 $file ${xslDir}/iso_dsdl_include.xsl allow-foreign=true
done

echo Transforming input files to XSLT - phase 2...
for file in `ls ${outputDir}/*.t1` 
do
    echo "   Transforming phase 2 `basename $file`" ;
    java -Xmx2048m -jar ${jarDir}/saxon-9/saxon9.jar -o ${outputDir}/`basename $file`.t2 $file ${xslDir}/iso_abstract_expand.xsl allow-foreign=true
done

echo Transforming input files to XSLT - phase 3...
for file in `ls ${outputDir}/*.t2` 
do
    echo "   Transforming phase 3 `basename $file`" ;
    java -Xmx2048m -jar ${jarDir}/saxon-9/saxon9.jar -o ${outputDir}/`basename $file`.t3 $file ${xslDir}/iso_schematron_message_xslt2.xsl allow-foreign=true
done

echo Removing temporary files ...
rm ${outputDir}/*.t1
rm ${outputDir}/*.t2

for file in `ls ${outputDir}/*.t3`
do 
    mv $file `echo $file | sed 's/\(.*\.\)sch.t1.t2.t3/\1xsl/'`
done

cd $currdir
