<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" exclude-result-prefixes="#all" xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" xmlns:html="http://www.w3.org/1999/xhtml">
    <xsl:output method="text"/>
    <xsl:output method="xhtml" indent="yes" name="xhtml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>
    <!--store variables-->
    <xsl:variable name="htmlInputPath" select="/system/@wsdlInputPath"/>
    <xsl:variable name="htmlOutputPath" select="/system/@wsdlOutputPath"/>
    <xsl:variable name="suffix" select="/system/@suffix"/>
    <xsl:variable name="defaultMessage">MCCI_IN000002</xsl:variable>
    <xsl:variable name="defaultBatchMessage">MCCI_IN200101</xsl:variable>
    <xsl:variable name="schemaPath">../schemas_codeGen/</xsl:variable>
    <xsl:variable name="exampleXmlPath">../</xsl:variable>
    <xsl:variable name="searchExampleXmlPath">../../</xsl:variable>
    <!-- This template is for the (primary) source xml with the list of wsdl's -->
    <xsl:template match="/system">
        <xsl:for-each select="wsdl">
            <xsl:variable name="version" select="
                    if (string-length(./@version) > 0) then
                        concat('-', ./@version)
                    else
                        ''"/>
            <xsl:variable name="htmlInputFile" select="concat($htmlInputPath, ./@name, $version, '_mep.xml')"/>
            <xsl:variable name="outputFilename" select="concat($htmlOutputPath, ./@name, $suffix, $version, '.html')"/>
            <xsl:variable name="wsdlInputDoc" select="document($htmlInputFile)"/>
            <xsl:variable name="wsdlName" select="$wsdlInputDoc/wsdl/@name"/>
            <xsl:variable name="serviceName" select="$wsdlInputDoc/wsdl/service/@name"/>
            <xsl:variable name="version" select="$wsdlInputDoc/wsdl/@version"/>
            <xsl:variable name="versionNeeded" select="string-length($version) > 0"/>
            <xsl:variable name="wsdlNameVersion" select="
                    concat($wsdlName, if ($versionNeeded) then
                        concat('-', $version)
                    else
                        '', $suffix)"/>
            <xsl:variable name="defaultNeeded" select="boolean($wsdlInputDoc//mep[string-length(out/@message) = 0 or string-length(in/@message) = 0])"/>
            <xsl:variable name="title" select="
                    concat($wsdlName, $suffix, if ($versionNeeded) then
                        concat(', versie ', $version)
                    else
                        '')"/>
            <xsl:variable name="batchNeeded" select="($wsdlInputDoc//mep[@batch = 'true'])"/>
            <!-- Output to log  -->
            <xsl:value-of select="concat('Creating ', $outputFilename, ' from ', $htmlInputFile)"/>
            <xsl:text>&#10;</xsl:text>
            <!-- Output to log  -->
            <xsl:result-document href="{$outputFilename}" format="xhtml">
                <!--                <xsl:apply-templates select="document($htmlInputFile)">
                    <xsl:with-param name="wsdlName" select="./@name"/>
                    </xsl:apply-templates>-->
                <html xmlns="http://www.w3.org/1999/xhtml">
                    <head>
                        <meta content="text/html;charset=UTF-8" http-equiv="Content-type"/>
                        <title>
                            <xsl:value-of select="$title"/>
                        </title>
                        <link rel="stylesheet" type="text/css" href="../css/nictiz.css"/>
                    </head>
                    <body>
                        <!-- page header -->
                        <table width="100%">
                            <tr>
                                <td valign="bottom">
                                    <h1>
                                        <xsl:value-of select="$title"/>
                                    </h1>
                                </td>
                                <td align="right">
                                    <div class="logo"/>
                                </td>
                            </tr>
                        </table>
                        <p/>
                        <table class="container">
                            <tr>
                                <td class="content">
                                    <xsl:comment> Normale interacties </xsl:comment>
                                    <xsl:comment> WSDL name </xsl:comment>
                                    <table class="values">
                                        <tr>
                                            <td class="value-label"> WSDL </td>
                                            <td class="value">
                                                <a>
                                                    <xsl:attribute name="href" select="concat('./', $wsdlNameVersion, '.wsdl')"/>
                                                    <xsl:value-of select="concat($wsdlNameVersion, '.wsdl')"/>
                                                </a>
                                            </td>
                                        </tr>
                                    </table>
                                    <xsl:comment> MEP <tr>
                                        <td><b>Message Exchange Pattern (XML):</b></td>
                                        <td><a href="./mep/{$wsdlNameVersion}_mep.xml"><xsl:value-of select="$wsdlNameVersion"/>_mep.xml</a></td>
                                    </tr>
                                    </xsl:comment>
                                    <xsl:comment> Service name </xsl:comment>
                                    <table class="values">
                                        <tr>
                                            <td class="value-label"> Service </td>
                                            <td class="value">
                                                <!-- Uitzondering voor Klantenloket WijzigenAutorisatieProfiel -->
                                                <xsl:choose>
                                                    <xsl:when test="contains($serviceName, 'WijzigenAutorisatieprofiel') and contains($suffix, 'Klantenloket')">
                                                        <xsl:value-of select="
                                                                concat($serviceName, if ($versionNeeded)
                                                                then
                                                                    concat('_', $version)
                                                                else
                                                                    '', '_Service')"/>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="
                                                                concat($serviceName, if ($versionNeeded)
                                                                then
                                                                    concat('_', $version)
                                                                else
                                                                    '', $suffix, '_Service')"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </td>
                                        </tr>
                                    </table>
                                    <xsl:comment>Service Location</xsl:comment>
                                    <table class="values">
                                        <tr>
                                            <td class="value-label"> Service Location </td>
                                            <td class="value">
                                                <xsl:choose>
                                                    <xsl:when test="contains($serviceName, 'WijzigenAutorisatieprofiel') and contains($suffix, 'Klantenloket')">
                                                        <xsl:value-of select="
                                                                concat($wsdlInputDoc//wsdl/@location,
                                                                if ($versionNeeded) then
                                                                    concat($version, '/')
                                                                else
                                                                    '', $serviceName)"/>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="
                                                                concat($wsdlInputDoc//wsdl/@location,
                                                                if ($versionNeeded) then
                                                                    concat($version, '/')
                                                                else
                                                                    '', concat($serviceName, $suffix))"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </td>
                                        </tr>
                                    </table>
                                    <xsl:comment>Diagram</xsl:comment>
                                    <table class="values">
                                        <tr>
                                            <td class="value-label"> Diagram </td>
                                            <td class="value">
                                                <table>
                                                    <tr>
                                                        <td> Communicatie op HTTP-niveau: <br/> Iedere pijl van client naar server is een HTTP-request, <br/> iedere pijl terug van server naar client daaronder is de bijbehorende HTTP response. </td>
                                                    </tr>
                                                    <tr>
                                                        <td>
                                                            <img alt="Grafische weergave webservice">
                                                                <xsl:attribute name="title" select="concat('./graphics/', $wsdlNameVersion, '.png')"/>
                                                                <xsl:attribute name="src" select="concat('./graphics/', $wsdlNameVersion, '.png')"/>
                                                            </img>
                                                        </td>
                                                    </tr>
                                                </table>
                                            </td>
                                        </tr>
                                    </table>
                                    <table class="values">
                                        <tr>
                                            <td>
                                                <h3>Operations</h3>
                                            </td>
                                        </tr>
                                    </table>
                                    <div class="level2">
                                        <!-- Operation -->
                                        <xsl:for-each select="$wsdlInputDoc//mep">
                                            <xsl:comment>Operation</xsl:comment>
                                            <h4>
                                                <xsl:value-of select="
                                                        concat($serviceName, if ($versionNeeded) then
                                                            $version
                                                        else
                                                            '', '_', ./@name)"/>
                                            </h4>
                                            <div class="level2">
                                                <table width="100%">
                                                    <!-- SOAP Action -->
                                                    <xsl:comment>soapAction</xsl:comment>
                                                    <tr>
                                                        <td class="labelSmall"> SOAP Action </td>
                                                        <td class="value">
                                                            <xsl:value-of select="
                                                                    concat('&quot;urn:hl7-org:v3/', $serviceName, if ($versionNeeded) then
                                                                        $version
                                                                    else
                                                                        '', '_', ./@name, '&quot;')"/>
                                                        </td>
                                                    </tr>
                                                    <!-- Input -->
                                                    <xsl:comment>Input</xsl:comment>
                                                    <tr>
                                                        <td class="labelSmall"> Input </td>
                                                        <td>
                                                            <table>
                                                                <tr>
                                                                    <td class="value">
                                                                        <!-- if there is a message, get the name otherwise get the default message -->
                                                                        <xsl:variable name="message">
                                                                            <xsl:choose>
                                                                                <xsl:when test="./in/@message">
                                                                                    <xsl:value-of select="./in/@message"/>
                                                                                </xsl:when>
                                                                                <xsl:otherwise>
                                                                                    <xsl:value-of select="$defaultMessage"/>
                                                                                </xsl:otherwise>
                                                                            </xsl:choose>
                                                                        </xsl:variable>
                                                                        <table>
                                                                            <tr>
                                                                                <td class="value-label" colspan="2">
                                                                                    <xsl:value-of select="concat('hl7:', $message)"/>
                                                                                </td>
                                                                            </tr>
                                                                            <tr>
                                                                                <td>
                                                                                    <xsl:call-template name="addXsd">
                                                                                        <xsl:with-param name="message" select="$message"/>
                                                                                    </xsl:call-template>
                                                                                </td>
                                                                            </tr>
                                                                        </table>
                                                                    </td>
                                                                </tr>
                                                            </table>
                                                        </td>
                                                    </tr>
                                                    <!-- Output -->
                                                    <xsl:comment>Output</xsl:comment>
                                                    <tr>
                                                        <td class="labelSmall"> Output </td>
                                                        <td>
                                                            <table>
                                                                <tr>
                                                                    <td class="value">
                                                                        <!-- if there is a message, get the name otherwise get the default message -->
                                                                        <xsl:variable name="message">
                                                                            <xsl:choose>
                                                                                <xsl:when test="./out/@message">
                                                                                    <xsl:value-of select="./out/@message"/>
                                                                                </xsl:when>
                                                                                <xsl:otherwise>
                                                                                    <xsl:value-of select="$defaultMessage"/>
                                                                                </xsl:otherwise>
                                                                            </xsl:choose>
                                                                        </xsl:variable>
                                                                        <xsl:choose>
                                                                            <!-- if there is a choice of response elements -->
                                                                            <xsl:when test="./out/element/@name">
                                                                                <table>
                                                                                    <tr>
                                                                                        <td class="labelSmall">
                                                                                            <xsl:value-of select="$message"/>
                                                                                            <br/> (Choice) </td>
                                                                                        <td>
                                                                                            <xsl:for-each select="./out/element/@name">
                                                                                                <table>
                                                                                                    <tr>
                                                                                                        <td class="value-label" colspan="2">
                                                                                                            <xsl:value-of select="concat('hl7:', .)"/>
                                                                                                        </td>
                                                                                                    </tr>
                                                                                                    <tr>
                                                                                                        <td>
                                                                                                            <xsl:call-template name="addXsd">
                                                                                                                <xsl:with-param name="message" select="."/>
                                                                                                            </xsl:call-template>
                                                                                                        </td>
                                                                                                    </tr>
                                                                                                </table>
                                                                                            </xsl:for-each>
                                                                                        </td>
                                                                                    </tr>
                                                                                </table>
                                                                            </xsl:when>
                                                                            <xsl:otherwise>
                                                                                <table>
                                                                                    <tr>
                                                                                        <td class="value-label" colspan="2">
                                                                                            <xsl:value-of select="concat('hl7:', $message)"/>
                                                                                        </td>
                                                                                    </tr>
                                                                                    <tr>
                                                                                        <td>
                                                                                            <xsl:call-template name="addXsd">
                                                                                                <xsl:with-param name="message" select="$message"/>
                                                                                            </xsl:call-template>
                                                                                        </td>
                                                                                    </tr>
                                                                                </table>
                                                                            </xsl:otherwise>
                                                                        </xsl:choose>
                                                                    </td>
                                                                </tr>
                                                            </table>
                                                        </td>
                                                    </tr>
                                                </table>
                                            </div>
                                            <p/>
                                        </xsl:for-each>
                                    </div>
                                    <!-- The batch specific stuff below should be removed after all legacy 'indirect opvragen'
                                        interaction have been removed-->
                                    <!-- batch interactie indien nodig -->
                                    <xsl:if test="$batchNeeded">
                                        <table class="values">
                                            <tr>
                                                <td>
                                                    <h2>Batch interacties</h2>
                                                </td>
                                            </tr>
                                        </table>
                                        <xsl:comment> Batch interacties </xsl:comment>
                                        <xsl:comment> WSDL name </xsl:comment>
                                        <table class="values">
                                            <tr>
                                                <td class="value-label"> WSDL </td>
                                                <td class="value">
                                                    <a>
                                                        <xsl:attribute name="href" select="concat('./', $wsdlNameVersion, '.wsdl')"/>
                                                        <xsl:value-of select="concat($wsdlNameVersion, '.wsdl')"/>
                                                    </a>
                                                </td>
                                            </tr>
                                        </table>
                                        <xsl:comment> MEP <tr>
                                            <td><b>Message Exchange Pattern (XML):</b></td>
                                            <td><a href="./mep/${specs.wsdlName}_mep.xml">${specs.wsdlName}_mep.xml</a></td>
                                        </tr>
                                        </xsl:comment>
                                        <xsl:comment> Service name </xsl:comment>
                                        <table class="values">
                                            <tr>
                                                <td class="value-label"> Service </td>
                                                <td class="value">
                                                    <xsl:value-of select="
                                                            concat($serviceName, if ($versionNeeded)
                                                            then
                                                                concat('-', $version)
                                                            else
                                                                '', '_Service')"/>
                                                </td>
                                            </tr>
                                        </table>
                                        <xsl:comment>Service Location</xsl:comment>
                                        <table class="values">
                                            <tr>
                                                <td class="value-label"> Service Location </td>
                                                <td class="value">
                                                    <xsl:value-of select="
                                                            concat($wsdlInputDoc//wsdl/@location,
                                                            if ($versionNeeded) then
                                                                concat($version, '/')
                                                            else
                                                                '', $serviceName, 'Batch')"/>
                                                </td>
                                            </tr>
                                        </table>
                                        <xsl:comment>Diagram</xsl:comment>
                                        <table class="values">
                                            <tr>
                                                <td class="value-label"> Diagram </td>
                                                <td class="value">
                                                    <table>
                                                        <tr>
                                                            <td> Communicatie op HTTP-niveau: <br/> Iedere pijl van client naar server is een HTTP-request, <br/> iedere pijl terug van server naar client daaronder is de bijbehorende HTTP response. </td>
                                                        </tr>
                                                        <tr>
                                                            <td>
                                                                <img alt="Grafische weergave webservice" title="Grafische weergave webservice">
                                                                    <xsl:attribute name="src" select="concat('./graphics/', $wsdlNameVersion, 'Batch.png')"/>
                                                                </img>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                </td>
                                            </tr>
                                        </table>
                                        <table class="values">
                                            <tr>
                                                <td>
                                                    <h3>Operations</h3>
                                                </td>
                                            </tr>
                                        </table>
                                        <div class="level2">
                                            <!-- Operation -->
                                            <xsl:for-each select="$wsdlInputDoc//mep[@batch = 'true']">
                                                <xsl:comment>Operation</xsl:comment>
                                                <h4>
                                                    <xsl:value-of select="concat($wsdlName, 'Batch_', ./@name)"/>
                                                </h4>
                                                <div class="level2">
                                                    <table width="100%">
                                                        <!-- SOAP Action -->
                                                        <xsl:comment>SOAP Action</xsl:comment>
                                                        <tr>
                                                            <td class="labelSmall"> SOAP Action </td>
                                                            <td class="value">
                                                                <xsl:value-of select="concat('&quot;urn:hl7-org:v3/', $serviceName, 'Batch_', ./@name, '&quot;')"/>
                                                            </td>
                                                        </tr>
                                                        <!-- Input -->
                                                        <xsl:comment>Input</xsl:comment>
                                                        <tr>
                                                            <td class="labelSmall"> Input </td>
                                                            <td>
                                                                <table>
                                                                    <tr>
                                                                        <td class="value">
                                                                            <!-- if there is a message, get the name otherwise get the default message -->
                                                                            <xsl:variable name="message">
                                                                                <xsl:choose>
                                                                                    <xsl:when test="./in/@message">
                                                                                        <xsl:value-of select="./in/@message"/>
                                                                                    </xsl:when>
                                                                                    <xsl:otherwise>
                                                                                        <xsl:value-of select="$defaultMessage"/>
                                                                                    </xsl:otherwise>
                                                                                </xsl:choose>
                                                                            </xsl:variable>
                                                                            <table>
                                                                                <tr>
                                                                                    <td class="value-label" colspan="2">
                                                                                        <xsl:value-of select="concat('hl7:', $message)"/>
                                                                                    </td>
                                                                                </tr>
                                                                                <tr>
                                                                                    <td>
                                                                                        <xsl:call-template name="addXsd">
                                                                                            <xsl:with-param name="message" select="$message"/>
                                                                                        </xsl:call-template>
                                                                                    </td>
                                                                                </tr>
                                                                            </table>
                                                                        </td>
                                                                    </tr>
                                                                </table>
                                                            </td>
                                                        </tr>
                                                        <!-- Output -->
                                                        <xsl:comment>Output</xsl:comment>
                                                        <tr>
                                                            <td class="labelSmall"> Output </td>
                                                            <td>
                                                                <table>
                                                                    <tr>
                                                                        <td class="value">
                                                                            <!--  get the default batch message -->
                                                                            <xsl:variable name="message" select="$defaultBatchMessage"/>
                                                                            <xsl:choose>
                                                                                <!-- if there is a choice of response elements -->
                                                                                <xsl:when test="./out/element/@name">
                                                                                    <table>
                                                                                        <tr>
                                                                                            <td class="labelSmall">
                                                                                                <xsl:value-of select="$message"/>
                                                                                                <br/> (Choice) </td>
                                                                                            <td>
                                                                                                <xsl:for-each select="./out/element/@name">
                                                                                                    <table>
                                                                                                        <tr>
                                                                                                            <td class="value-label" colspan="2">
                                                                                                                <xsl:value-of select="concat('hl7:', .)"/>
                                                                                                            </td>
                                                                                                        </tr>
                                                                                                        <tr>
                                                                                                            <td>
                                                                                                                <xsl:call-template name="addXsd">
                                                                                                                    <xsl:with-param name="message" select="."/>
                                                                                                                </xsl:call-template>
                                                                                                            </td>
                                                                                                        </tr>
                                                                                                    </table>
                                                                                                </xsl:for-each>
                                                                                            </td>
                                                                                        </tr>
                                                                                    </table>
                                                                                </xsl:when>
                                                                                <xsl:otherwise>
                                                                                    <table>
                                                                                        <tr>
                                                                                            <td class="value-label" colspan="2">
                                                                                                <xsl:value-of select="concat('hl7:', $message)"/>
                                                                                            </td>
                                                                                        </tr>
                                                                                        <tr>
                                                                                            <td>
                                                                                                <xsl:call-template name="addXsd">
                                                                                                    <xsl:with-param name="message" select="$message"/>
                                                                                                </xsl:call-template>
                                                                                            </td>
                                                                                        </tr>
                                                                                    </table>
                                                                                </xsl:otherwise>
                                                                            </xsl:choose>
                                                                        </td>
                                                                    </tr>
                                                                </table>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                </div>
                                                <p/>
                                            </xsl:for-each>
                                        </div>
                                    </xsl:if>
                                    <!-- end Batch needed -->
                                </td>
                            </tr>
                        </table>
                    </body>
                </html>
            </xsl:result-document>
        </xsl:for-each>
    </xsl:template>
    <!-- Named template which is called from appropriate location to add xsd -->
    <xsl:template name="addXsd" xmlns="http://www.w3.org/1999/xhtml">
        <xsl:param name="message">defaultInputMessageName</xsl:param>
        <xsl:variable name="exampleMessage">
            <xsl:value-of select="concat(tokenize($message, '_')[1], '_EX', substring(tokenize($message, '_')[2], 3, 6))"/>
        </xsl:variable>
        <table>
            <tr>
                <td class="labelSmall">Schema</td>
                <td>
                    <a>
                        <xsl:attribute name="href">
                            <xsl:value-of select="concat($schemaPath, $message, '.xsd')"/>
                        </xsl:attribute>
                        <xsl:value-of select="concat($message, '.xsd')"/>
                    </a>
                </td>
            </tr>
            <tr>
                <td class="labelSmall">Voorbeelden</td>
                <td>
                    <xsl:for-each select="collection(iri-to-uri(concat($searchExampleXmlPath, '?select=', $exampleMessage, '*.xml;recurse=yes')))">
                        <xsl:sort select="tokenize(document-uri(.), '/')[last()]"/>
                        <xsl:variable name="fileName" select="tokenize(document-uri(.), '/')[last()]"/>
                        <xsl:text>
                        </xsl:text>
                        <a>
                            <xsl:attribute name="href">
                                <xsl:value-of select="concat($exampleXmlPath, tokenize(document-uri(.), '/')[last() - 1], '/', $fileName)"/>
                            </xsl:attribute>
                            <xsl:value-of select="$fileName"/>
                        </a>
                        <xsl:text> </xsl:text>
                    </xsl:for-each>
                </td>
            </tr>
        </table>
    </xsl:template>
</xsl:stylesheet>
