<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" exclude-result-prefixes="#all">

    <xsl:output method="text"/>
    <xsl:output method="xhtml" indent="yes" name="xhtml" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
        doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>

    <xsl:param name="mepPath" select="system/@wsdlInputPath"/>
    <xsl:param name="outputFilename" select="concat(/system/@wsdlOutputPath, 'index.html')"/>

    <!--store variables-->
    <xsl:variable name="defaultMessage">MCCI_IN000002</xsl:variable>
    <xsl:variable name="schemaPath">../schemas_codeGen/</xsl:variable>
    <xsl:variable name="wsdlPath">./</xsl:variable>

    <xsl:template match="/">
        <!-- Output to log  -->
        <xsl:value-of select="concat('Creating ', $outputFilename)"/>
        <xsl:text>
</xsl:text>
        <!-- Output to log  -->
        <xsl:result-document href="{$outputFilename}" format="xhtml">
            <html xmlns="http://www.w3.org/1999/xhtml">
                <head>
                    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                    <title>WSDL bestanden</title>
                    <link rel="stylesheet" type="text/css" href="../css/nictiz.css"/>
                    <script type="text/javascript" src="../css/gs_sortable.js"/>
                    <script type="text/javascript">
                        var TSort_Data = new Array ('wsdlList', 's', 's', 's');
                        var TSort_Initial = 0;
                        var TSort_Classes = new Array ('plain', 'alternate');
                        tsRegister();
                </script>
                </head>
                <body>
                    <table width="100%">
                        <tr>
                            <td valign="bottom">
                                <h1> WSDL bestanden voor <xsl:value-of select="/system/@description"/>
                                </h1>
                            </td>
                            <td align="right">
                                <div class="logo"/>
                            </td>
                        </tr>
                    </table>
                    <p/>
                    <table class="container">
                        <tr>
                            <td class="content">
                                <table>
                                    <tr>
                                        <td>
                                            <div class="level2">
                                                <div class="paragraph">Hieronder een overzicht van alle Webservices, met hun WSDL en documentatie. In
                                                    alle gevallen is de WSDL de normatieve beschrijving van de Webservice, en is de documentatie
                                                    aanvullend. De vierde kolom toont de interactieschema's van de berichten die in de webservice
                                                    gebruikt worden.</div>
                                                <table class="values" id="wsdlList">
                                                    <thead>
                                                        <tr>
                                                            <th class="larger">Webservice</th>
                                                            <th class="larger">WSDL</th>
                                                            <th class="larger">Documentatie</th>
                                                            <th class="larger">Schema's</th>
                                                        </tr>
                                                    </thead>
                                                    <xsl:call-template name="addWsdlInfo"/>
                                                </table>
                                            </div>
                                        </td>
                                    </tr>
                                </table>
                            </td>
                        </tr>
                    </table>
                </body>
            </html>
        </xsl:result-document>
    </xsl:template>

    <!-- Named template which is called from appropriate location to add wsdl information -->
    <xsl:template name="addWsdlInfo" xmlns="http://www.w3.org/1999/xhtml">
        <xsl:variable name="suffix" select="/system/@suffix"/>

        <xsl:for-each select="/system/wsdl">
            <xsl:variable name="version" select="if (string-length(./@version)>0) then concat('-', ./@version) else '' "/>
            <xsl:variable name="mepFilename" select="concat($mepPath, ./@name, $version, '_mep.xml')"/>
            <xsl:variable name="mepXml" select="document($mepFilename)"/>
            <xsl:variable name="wsdlName" select="concat(./@name,$suffix)"/>

            <tr>
                <td valign="top">
                    <xsl:value-of select="$wsdlName"/>
                </td>
                <td valign="top">
                    <a>
                        <xsl:attribute name="href">
                            <xsl:value-of select="concat($wsdlPath, $wsdlName, $version,'.wsdl')"/>
                        </xsl:attribute>
                        <xsl:value-of select="concat($wsdlName, $version,'.wsdl')"/>
                    </a>
                </td>
                <td valign="top">
                    <a>
                        <xsl:attribute name="href">
                            <xsl:value-of select="concat($wsdlPath, $wsdlName, $version,'.html')"/>
                        </xsl:attribute>
                        <xsl:value-of select="concat($wsdlName, $version, '.html')"/>
                    </a>
                </td>
                <td>
                    <!-- Add the necessary xsd's -->
                    <xsl:variable name="uniqueListMessages"
                        select="$mepXml//mep/*[string-length(element[1]/@name)=0]/@message[not(.=following::*/@message)]"/>
                    <xsl:for-each select="$uniqueListMessages">
                        <xsl:call-template name="addHref">
                            <xsl:with-param name="message">
                                <xsl:value-of select="."/>
                            </xsl:with-param>
                        </xsl:call-template>
                    </xsl:for-each>
                    <!--  Add includes for the elements of the composed messages, only the unique element names  -->
                    <xsl:variable name="uniqueListElementNames" select="$mepXml//mep/*/element/@name[not(.=following::element/@name)]"/>
                    <xsl:for-each select="$uniqueListElementNames">
                        <xsl:call-template name="addHref">
                            <xsl:with-param name="message">
                                <xsl:value-of select="."/>
                            </xsl:with-param>
                        </xsl:call-template>
                    </xsl:for-each>

                    <!-- Add the includes for the default messages, if needed -->
                    <xsl:variable name="defaultNeeded"
                        select="($mepXml//mep[string-length(out/@message)=0 or string-length(in/@message)=0]) and not($mepXml//@message=defaultMessage)"/>
                    <xsl:if test="$defaultNeeded">
                        <xsl:call-template name="addHref">
                            <xsl:with-param name="message">
                                <xsl:value-of select="$defaultMessage"/>
                            </xsl:with-param>
                        </xsl:call-template>
                    </xsl:if>
                </td>
            </tr>
        </xsl:for-each>
    </xsl:template>

    <!-- Named template which is called from appropriate location to add href, defaulted to xsd -->
    <xsl:template name="addHref" xmlns="http://www.w3.org/1999/xhtml">
        <xsl:param name="path">
            <xsl:value-of select="$schemaPath"/>
        </xsl:param>
        <xsl:param name="message">defaultInputMessageName</xsl:param>
        <xsl:param name="extension">xsd</xsl:param>
        <div style="font-size:smaller;">
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="concat($path, $message, '.', $extension)"/>
                </xsl:attribute>
                <xsl:value-of select="concat($message, '.', $extension)"/>
            </a>
        </div>
    </xsl:template>

</xsl:stylesheet>
