<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/"
    xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/" xmlns:svg="http://www.w3.org/2000/svg">

    <xsl:output method="text"/>
    <xsl:output method="xml" indent="yes" name="xml"/>

    <!--store variables-->
    <xsl:variable name="svgOutputPath" select="/system/@svgOutputPath"/>
    <xsl:variable name="suffix" select="/system/@suffix"/>
    <xsl:variable name="inputDir" select="/system/@wsdlInputPath"/>
    <xsl:variable name="outputDir" select="/system/@wsdlOutputPath"/>

    <!-- This template is for the (primary) source xml -->
    <xsl:template match="/system">
        <xsl:for-each select="wsdl">
            <xsl:variable name="versionF" select="if (string-length(./@version)>0) then concat('-', ./@version) else '' "/>
            <xsl:variable name="outputFilename" select="concat($svgOutputPath, ./@name, $suffix, $versionF, '.svg')"/>
            <xsl:variable name="wsdlName" select="./@name"/>
            <xsl:variable name="version" select="./@version"/>
            <xsl:variable name="versionNeeded" select="string-length($version)>0"/>
            <xsl:variable name="wsdlNameVersion" select="concat($wsdlName, $suffix, if ($versionNeeded) then concat('-', $version) else '')"/>
            <xsl:variable name="wsdlFileName" select="concat($outputDir, $wsdlNameVersion, '.wsdl')"/>
            <xsl:variable name="wsdlDoc" select="document($wsdlFileName)"/>
            <xsl:variable name="defaultMessage">hl7:MCCI_IN000002</xsl:variable>
            <xsl:variable name="defaultBatchMessage">hl7:MCCI_IN200101</xsl:variable>

            <!-- input mep file -->
            <xsl:variable name="mepInputFile" select="concat($inputDir, ./@name, $versionF, '_mep.xml')"/>
            <xsl:variable name="mepInputDoc" select="document($mepInputFile)"/>

            <xsl:variable name="serviceName" select="$mepInputDoc/wsdl/service[1]/@name"/>
            <xsl:variable name="batchNeeded" select="($mepInputDoc//mep[@batch='true'])"/>
            <xsl:variable name="amountMep" select="count($mepInputDoc/wsdl/service/mep)"/>
            <xsl:variable name="amountBatchMep" select="count($mepInputDoc/wsdl/service/mep[@batch='true'])"/>
            <xsl:variable name="maxOperationName" select="max($wsdlDoc/wsdl:definitions/wsdl:portType/wsdl:operation/@name/string-length() )"/>
            <xsl:variable name="widthPinkRect">
                <xsl:value-of select="10 + $maxOperationName*6"/>
            </xsl:variable>
            <xsl:variable name="arrowLength">
                <xsl:value-of select="140 + $maxOperationName*6"/>
            </xsl:variable>
            <xsl:variable name="width">
                <xsl:value-of select="130 + $arrowLength"/>
            </xsl:variable>
            <xsl:variable name="offsetPinkRectY" select="-430"/>
            <xsl:variable name="offsetPinkRectX" select="-1425"/>
            <xsl:variable name="offsetTextInPinkRectY" select="13"/>
            <xsl:variable name="offsetTextInPinkRectX" select="5"/>

            <!-- Output to log  -->
            <xsl:value-of
                select="concat(format-dateTime(current-dateTime(), 
               '[Y]-[M,2]-[D,2] [H,2]:[m,2]:[s,2]') ,
               '. Creating ', $outputFilename)"/>
            <xsl:text>
</xsl:text>
            <!-- End Output to log  -->

            <xsl:result-document href="{$outputFilename}" format="xml">
                <svg xmlns="http://www.w3.org/2000/svg" width="500" height="440" id="svg2" version="1.1">
                    <xsl:attribute name="height" select="140 + ($amountMep * 100)"/>
                    <xsl:attribute name="width" select="$width"/>
                    <g id="layer1" transform="translate(1480.6,423.53786)">
                        <rect
                            style="fill:#ffffff;fill-opacity:1;stroke:#000000;stroke-width:0.16482493;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none"
                            id="backgroundObject" width="499.83517" height="239.83517" x="-1480.5176" y="-423.45544">
                            <xsl:attribute name="height" select="139.9 + ($amountMep * 100)"/>
                            <xsl:attribute name="width" select="$width - 0.1"/>
                            <desc>Background rectangle in white to avoid transparency.</desc>
                        </rect>

                        <g id="g3641" transform="translate(0,8.5)">
                            <!-- Service name -->
                            <text
                                style="font-size:12px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:middle;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans"
                                x="-1425" y="-380" id="textService">
                                <xsl:attribute name="x" select="-1425 + ($arrowLength div 2)"/>
                                <desc id="desc21">Title of service</desc>
                                <xsl:value-of select="concat($serviceName,$suffix)"/>
                            </text>

                            <!-- for each mep in the mep file (operation in the wsdl) the pink rectangle and operationName -->
                            <xsl:for-each select="$wsdlDoc/wsdl:definitions/wsdl:portType/wsdl:operation">
                                <xsl:variable name="wsdlOperationName" select="@name"/>
                                <g id="operationName">
                                    <xsl:attribute name="id" select="concat('operationName_', position())"/>
                                    <rect y="-330" x="-1395" height="17" width="225" id="pinkRect"
                                        style="font-size:10px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:center;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffaaaa;fill-opacity:1;font-family:Bitstream Vera Sans">
                                        <xsl:attribute name="id" select="concat('pinkRect_', position())"/>
                                        <xsl:attribute name="y" select="$offsetPinkRectY + (position() * 104)"/>
                                        <xsl:attribute name="x" select="$offsetPinkRectX + ($arrowLength div 2) - ($widthPinkRect div 2) "/>
                                        <xsl:attribute name="width" select="$widthPinkRect"/>
                                    </rect>
                                    <text id="operationText" y="-317" x="-1390"
                                        style="font-size:10px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:center;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans">
                                        <xsl:attribute name="id" select="concat('operationText_', position())"/>
                                        <xsl:attribute name="y" select="$offsetPinkRectY + $offsetTextInPinkRectY + (position() * 104)"/>
                                        <xsl:attribute name="x" select="$offsetPinkRectX + $offsetTextInPinkRectX + ($arrowLength div 2) - ($widthPinkRect div 2)"/>
                                        <xsl:value-of select="$wsdlOperationName"/>
                                    </text>
                                </g>
                            </xsl:for-each>
                        </g>

                        <!-- for each mep the input and output message -->
                        <xsl:for-each select="$mepInputDoc/wsdl/service/mep">
                            <text
                                style="font-size:10.5px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:center;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans"
                                x="-1270" y="-273" id="inMessage">
                                <xsl:attribute name="id" select="concat('inMessage_', position())"/>
                                <xsl:attribute name="y" select="-386 + (position() * 104)"/>
                                <xsl:attribute name="x" select="-1475 + ($arrowLength div 2)"/>
                                <xsl:value-of select="concat('hl7:', ./in/@message)"/>
                            </text>
                            <text
                                style="font-size:10.5px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:center;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans"
                                x="-1270" y="-250" id="outMessage">
                                <xsl:attribute name="id" select="concat('outMessage_', position())"/>
                                <xsl:attribute name="y" select="-355 + (position() * 104)"/>
                                <xsl:attribute name="x" select="-1475 + ($arrowLength div 2)"/>
                                <xsl:if test="string-length(./out/@message)=0">
                                    <xsl:value-of select="$defaultMessage"/>
                                </xsl:if>
                                <xsl:if test="string-length(./out/@message)>0">
                                    <xsl:value-of select="concat('hl7:', ./out/@message)"/>
                                </xsl:if>
                            </text>
                        </xsl:for-each>

                        <!-- Client box to bar connect -->
                        <path style="fill:none;stroke:#000000;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
                            d="m -1430, -360 v 30" id="path3646">
                            <desc id="desc3635">Client box to bar connector</desc>
                        </path>
                        <!-- Client box (header) -->
                        <g id="g4324">
                            <rect y="-410" x="-1470" height="50" width="80" id="clientBox"
                                style="fill:#c4e1ff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:0.2000106;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none">
                                <desc id="desc2842">Header box for client</desc>
                            </rect>
                            <text id="text4304" y="-380" x="-1446.5"
                                style="font-size:10px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:start;line-height:100%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans"
                                >Client</text>
                        </g>

                        <!-- Server box -->
                        <g id="g4318">
                            <rect
                                style="fill:#c4e1ff;fill-opacity:1;stroke:#000000;stroke-width:0.2;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none"
                                y="-410" x="-1100" height="50" width="80" id="rect2844">
                                <xsl:attribute name="x" select="-1425+$arrowLength+5-40"/>
                            </rect>
                            <text id="serverBoxText" y="-379.77942" x="-1030" style="font-size:10px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:start;line-height:100%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans" xml:space="preserve"><xsl:attribute name="x" select="-1425 + $arrowLength - 13"/><desc id="desc4316">Could add application role here</desc>Server</text>
                        </g>

                        <!-- Arrows Client to Server to Client -->
                        <xsl:for-each select="$mepInputDoc/wsdl/service[1]/mep">
                            <g id="gArrowServerToClient">
                                <xsl:attribute name="id" select="concat('gArrowServerToClient_', position())"/>
                                <path id="ArrowServerToClient" d="m -1064.6713,-235.63193 c -359.3966,0 -359.3966,0 -359.3966,0"
                                    style="fill:none;stroke:#000000;stroke-width:1.00061953;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;marker-end:none">
                                    <xsl:attribute name="id" select="concat('ArrowServerToClient_', position())"/>
                                    <xsl:attribute name="d"
                                        select="concat('m ', -1425 + $arrowLength, ', ' , -350 + (position()*104), ' h -', $arrowLength)"/>
                                    <desc id="desc4292"><xsl:attribute name="id" select="concat('desc4292_', position())"/> This is the responding
                                        arrow</desc>
                                </path>
                                <!-- The arrow head server to client -->
                                <path
                                    d="m -1412.9219,-230.37783 0.4062,-9.99174 c -3.3774,1.28641 -6.7547,2.57283 -10.132,3.85925 0,0 0,0 0,0 -0.4815,0.18338 -0.9629,0.36676 -1.4444,0.55014 0,0 0,0 0,0 -0.076,0.0291 -0.153,0.0583 -0.2295,0.0874 0,0 0,0 0,0 0,0 0,0 0,0 -0.015,0.0176 -0.029,0.0231 -0.043,0.0246 0,0 0,0 0,0 -0.01,5.5e-4 -0.01,5.8e-4 -0.015,4.1e-4 -0,-6e-5 -0,-6e-5 -0,-6e-5 0,0 0,0 0,9e-5 0.01,2.6e-4 0.01,6.3e-4 0.015,0.002 0,0 0,0 0,0 0.014,0.003 0.028,0.009 0.041,0.028 0,0 0,0 0,0 0,0 0,0 0,0 0.074,0.0353 0.1478,0.0705 0.2216,0.10576 0.465,0.22185 0.93,0.44371 1.395,0.66556 3.2617,1.55631 6.5235,3.11262 9.7853,4.66892 z"
                                    style="fill:#000000;fill-rule:evenodd;stroke:none">
                                    <xsl:attribute name="id" select="concat('pathTriangleS2C_', position())"/>
                                    <xsl:attribute name="d"
                                        select="concat('m -1416,', -345 + (position()*104), ' 0.4062,-9.99174 c -3.3774,1.28641 -6.7547,2.57283 -10.132,3.85925 0,0 0,0 0,0 -0.4815,0.18338 -0.9629,0.36676 -1.4444,0.55014 0,0 0,0 0,0 -0.076,0.0291 -0.153,0.0583 -0.2295,0.0874 0,0 0,0 0,0 0,0 0,0 0,0 -0.015,0.0176 -0.029,0.0231 -0.043,0.0246 0,0 0,0 0,0 -0.01,5.5e-4 -0.01,5.8e-4 -0.015,4.1e-4 -0,-6e-5 -0,-6e-5 -0,-6e-5 0,0 0,0 0,9e-5 0.01,2.6e-4 0.01,6.3e-4 0.015,0.002 0,0 0,0 0,0 0.014,0.003 0.028,0.009 0.041,0.028 0,0 0,0 0,0 0,0 0,0 0,0 0.074,0.0353 0.1478,0.0705 0.2216,0.10576 0.465,0.22185 0.93,0.44371 1.395,0.66556 3.2617,1.55631 6.5235,3.11262 9.7853,4.66892 z')"
                                    />
                                </path>
                            </g>
                            <g id="gArrowClientToServer">
                                <xsl:attribute name="id" select="concat('gArrowClientToServer_', position())"/>
                                <path id="ArrowClientToServer" d="m -1425,-273.03637 l 358.9428,0"
                                    style="fill:none;stroke:#000000;stroke-width:0.99702412px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;marker-end:none">
                                    <xsl:attribute name="id" select="concat('ArrowClientToServer_', position())"/>
                                    <xsl:attribute name="d" select="concat('m -1425,', -381 + (position()*104), ' h ', $arrowLength)"/>
                                    <desc id="desc4290">
                                        <xsl:attribute name="id" select="concat('desc4290', position())"/> This is the initiating arrow</desc>
                                </path>
                                <!-- arrow head client to server -->
                                <path
                                    d="m -1076.6057,-278.23492 0.2428,9.99706 c 3.8451,-1.75975 7.6902,-3.51949 11.5354,-5.27924 0,-0.002 0,-0.002 0,-0.002 0,0 0,0 -0,-0.002 -3.926,-1.57108 -7.852,-3.14216 -11.7781,-4.71324 z"
                                    style="fill:#000000;fill-rule:evenodd;stroke:none">
                                    <xsl:attribute name="id" select="concat('pathTriangleC2S_', position())"/>
                                    <xsl:attribute name="d"
                                        select="concat('m ', -1435 + $arrowLength, ',', -387.5 + (position()*104.5), ' 0.2428,9.99706 c 3.8451,-1.75975 7.6902,-3.51949 11.5354,-5.27924 0,-0.002 0,-0.002 0,-0.002 0,0 0,0 -0,-0.002 -3.926,-1.57108 -7.852,-3.14216 -11.7781,-4.71324 z')"
                                    />
                                </path>
                            </g>
                        </xsl:for-each>

                        <!-- Server bar -->
                        <rect y="-330" x="-1035" height="330" width="10" id="rectServerBar"
                            style="fill:#c4e1ff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:0.37758133;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none">
                            <xsl:attribute name="x" select="-1425 + $arrowLength"/>
                            <xsl:attribute name="height" select="10 + $amountMep*104"/>
                            <desc id="desc2864">Server bar</desc>
                        </rect>
                        <!-- Server box to bar line -->
                        <path style="fill:none;stroke:#000000;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
                            d="m -1020, -360 v 30" id="path2872">
                            <xsl:attribute name="d" select="concat('m ', (-1425 + $arrowLength + 5) , ', -360 v 30')"/>
                        </path>
                        <!-- Client bar -->
                        <rect y="-330" x="-1435" height="330" width="10" id="rectClientBar"
                            style="fill:#c4e1ff;fill-opacity:1;stroke:#000000;stroke-width:0.35658869;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none">
                            <xsl:attribute name="height" select="10 + $amountMep*104"/>
                            <desc id="desc2880">Client bar</desc>
                        </rect>
                    </g>
                </svg>
            </xsl:result-document>

            <!-- generate graphic for old legacy 'indirect opvragen' batch operations -->
            <!-- This section should be removed after these legacy wsdl's have been phased out!!! -->
            <xsl:if test="$batchNeeded">
                <xsl:variable name="outputFilenameBatch" select="concat($svgOutputPath, ./@name, 'Batch', $suffix, $versionF, '.svg')"/>
                <xsl:result-document href="{$outputFilenameBatch}" format="xml">
                    <svg xmlns="http://www.w3.org/2000/svg" width="500" height="440" id="svg2" version="1.1">
                        <xsl:attribute name="height" select="140 + ($amountMep * 100)"/>
                        <xsl:attribute name="width" select="$width"/>
                        <g id="layer1" transform="translate(1480.6,423.53786)">
                            <rect
                                style="fill:#ffffff;fill-opacity:1;stroke:#000000;stroke-width:0.16482493;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none"
                                id="backgroundObject" width="499.83517" height="239.83517" x="-1480.5176" y="-423.45544">
                                <xsl:attribute name="height" select="139.9 + ($amountMep * 100)"/>
                                <xsl:attribute name="width" select="$width - 0.1"/>
                                <desc>Background rectangle in white to avoid transparency.</desc>
                            </rect>

                            <g id="g3641" transform="translate(0,8.5)">
                                <!-- Service name -->
                                <text
                                    style="font-size:12px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:start;line-height:125%;writing-mode:lr-tb;text-anchor:middle;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans"
                                    x="-1425" y="-380" id="textService">
                                    <xsl:attribute name="x" select="-1425 + ($arrowLength div 2)"/>
                                    <desc id="desc21">Title of service</desc>
                                    <xsl:value-of select="concat($serviceName,$suffix)"/>
                                </text>

                                <!-- for each Batch operation in the wsdl file the pink rectangle and operationName -->
                                <xsl:for-each select="$wsdlDoc/wsdl:definitions/wsdl:portType/wsdl:operation[contains(@name,'Batch')]">
                                    <g id="operationName">
                                        <xsl:attribute name="id" select="concat('operationName_', position())"/>
                                        <rect y="-330" x="-1395" height="17" width="225" id="pinkRect"
                                            style="font-size:10px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:center;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#ffaaaa;fill-opacity:1;font-family:Bitstream Vera Sans">
                                            <xsl:attribute name="id" select="concat('pinkRect_', position())"/>
                                            <xsl:attribute name="y" select="$offsetPinkRectY + (position() * 104)"/>
                                            <xsl:attribute name="x" select="$offsetPinkRectX + ($arrowLength div 2) - ($widthPinkRect div 2) "/>
                                            <xsl:attribute name="width" select="$widthPinkRect"/>
                                        </rect>
                                        <text id="operationText" y="-317" x="-1390"
                                            style="font-size:10px;font-style:normal;font-variant:normal;font-weight:normal;font-stretch:normal;text-align:center;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans">
                                            <xsl:attribute name="id" select="concat('operationText_', position())"/>
                                            <xsl:attribute name="y" select="$offsetPinkRectY + $offsetTextInPinkRectY + (position() * 104)"/>
                                            <xsl:attribute name="x"
                                                select="$offsetPinkRectX + $offsetTextInPinkRectX + ($arrowLength div 2) - ($widthPinkRect div 2)"/>
                                            <xsl:value-of select="./@name"/>
                                        </text>
                                    </g>
                                </xsl:for-each>
                            </g>

                            <!-- for each Batch operation the input and output message from the wsdl -->
                            <xsl:for-each select="$wsdlDoc/wsdl:definitions/wsdl:portType/wsdl:operation[contains(@name,'Batch')]">
                                <text
                                    style="font-size:10.5px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:center;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans"
                                    x="-1270" y="-273" id="inMessage">
                                    <xsl:attribute name="id" select="concat('inMessage_', position())"/>
                                    <xsl:attribute name="y" select="-386 + (position() * 104)"/>
                                    <xsl:attribute name="x" select="-1475 + ($arrowLength div 2)"/>
                                    <xsl:value-of select="./wsdl:input/@message"/>
                                </text>
                                <text
                                    style="font-size:10.5px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:center;line-height:125%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans"
                                    x="-1270" y="-250" id="outMessage">
                                    <xsl:attribute name="id" select="concat('outMessage_', position())"/>
                                    <xsl:attribute name="y" select="-355 + (position() * 104)"/>
                                    <xsl:attribute name="x" select="-1475 + ($arrowLength div 2)"/>
                                    <xsl:value-of select="./wsdl:output/@message"/>
                                </text>
                            </xsl:for-each>

                            <!-- Client box to bar connect -->
                            <path style="fill:none;stroke:#000000;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
                                d="m -1430, -360 v 30" id="path3646">
                                <desc id="desc3635">Client box to bar connector</desc>
                            </path>
                            <!-- Client box (header) -->
                            <g id="g4324">
                                <rect y="-410" x="-1470" height="50" width="80" id="clientBox"
                                    style="fill:#c4e1ff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:0.2000106;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none">
                                    <desc id="desc2842">Header box for client</desc>
                                </rect>
                                <text id="text4304" y="-380" x="-1446.5"
                                    style="font-size:10px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:start;line-height:100%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans"
                                    >Client</text>
                            </g>

                            <!-- Server box -->
                            <g id="g4318">
                                <rect
                                    style="fill:#c4e1ff;fill-opacity:1;stroke:#000000;stroke-width:0.2;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none"
                                    y="-410" x="-1100" height="50" width="80" id="rect2844">
                                    <xsl:attribute name="x" select="-1425+$arrowLength+5-40"/>
                                </rect>
                                <text id="serverBoxText" y="-379.77942" x="-1030" style="font-size:10px;font-style:normal;font-variant:normal;font-weight:bold;font-stretch:normal;text-align:start;line-height:100%;writing-mode:lr-tb;text-anchor:start;fill:#000000;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans" xml:space="preserve"><xsl:attribute name="x" select="-1425 + $arrowLength - 13"/><desc id="desc4316">Could add application role here</desc>Server</text>
                            </g>

                            <!-- Arrows Client to Server to Client -->
                            <xsl:for-each select="$mepInputDoc/wsdl/service[1]/mep">
                                <g id="gArrowServerToClient">
                                    <xsl:attribute name="id" select="concat('gArrowServerToClient_', position())"/>
                                    <path id="ArrowServerToClient" d="m -1064.6713,-235.63193 c -359.3966,0 -359.3966,0 -359.3966,0"
                                        style="fill:none;stroke:#000000;stroke-width:1.00061953;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none;marker-end:none">
                                        <xsl:attribute name="id" select="concat('ArrowServerToClient_', position())"/>
                                        <xsl:attribute name="d"
                                            select="concat('m ', -1425 + $arrowLength, ', ' , -350 + (position()*104), ' h -', $arrowLength)"/>
                                        <desc id="desc4292"><xsl:attribute name="id" select="concat('desc4292_', position())"/> This is the responding
                                            arrow</desc>
                                    </path>
                                    <!-- The arrow head server to client -->
                                    <path
                                        d="m -1412.9219,-230.37783 0.4062,-9.99174 c -3.3774,1.28641 -6.7547,2.57283 -10.132,3.85925 0,0 0,0 0,0 -0.4815,0.18338 -0.9629,0.36676 -1.4444,0.55014 0,0 0,0 0,0 -0.076,0.0291 -0.153,0.0583 -0.2295,0.0874 0,0 0,0 0,0 0,0 0,0 0,0 -0.015,0.0176 -0.029,0.0231 -0.043,0.0246 0,0 0,0 0,0 -0.01,5.5e-4 -0.01,5.8e-4 -0.015,4.1e-4 -0,-6e-5 -0,-6e-5 -0,-6e-5 0,0 0,0 0,9e-5 0.01,2.6e-4 0.01,6.3e-4 0.015,0.002 0,0 0,0 0,0 0.014,0.003 0.028,0.009 0.041,0.028 0,0 0,0 0,0 0,0 0,0 0,0 0.074,0.0353 0.1478,0.0705 0.2216,0.10576 0.465,0.22185 0.93,0.44371 1.395,0.66556 3.2617,1.55631 6.5235,3.11262 9.7853,4.66892 z"
                                        style="fill:#000000;fill-rule:evenodd;stroke:none">
                                        <xsl:attribute name="id" select="concat('pathTriangleS2C_', position())"/>
                                        <xsl:attribute name="d"
                                            select="concat('m -1416,', -345 + (position()*104), ' 0.4062,-9.99174 c -3.3774,1.28641 -6.7547,2.57283 -10.132,3.85925 0,0 0,0 0,0 -0.4815,0.18338 -0.9629,0.36676 -1.4444,0.55014 0,0 0,0 0,0 -0.076,0.0291 -0.153,0.0583 -0.2295,0.0874 0,0 0,0 0,0 0,0 0,0 0,0 -0.015,0.0176 -0.029,0.0231 -0.043,0.0246 0,0 0,0 0,0 -0.01,5.5e-4 -0.01,5.8e-4 -0.015,4.1e-4 -0,-6e-5 -0,-6e-5 -0,-6e-5 0,0 0,0 0,9e-5 0.01,2.6e-4 0.01,6.3e-4 0.015,0.002 0,0 0,0 0,0 0.014,0.003 0.028,0.009 0.041,0.028 0,0 0,0 0,0 0,0 0,0 0,0 0.074,0.0353 0.1478,0.0705 0.2216,0.10576 0.465,0.22185 0.93,0.44371 1.395,0.66556 3.2617,1.55631 6.5235,3.11262 9.7853,4.66892 z')"
                                        />
                                    </path>
                                </g>
                                <g id="gArrowClientToServer">
                                    <xsl:attribute name="id" select="concat('gArrowClientToServer_', position())"/>
                                    <path id="ArrowClientToServer" d="m -1425,-273.03637 l 358.9428,0"
                                        style="fill:none;stroke:#000000;stroke-width:0.99702412px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1;marker-end:none">
                                        <xsl:attribute name="id" select="concat('ArrowClientToServer_', position())"/>
                                        <xsl:attribute name="d" select="concat('m -1425,', -381 + (position()*104), ' h ', $arrowLength)"/>
                                        <desc id="desc4290">
                                            <xsl:attribute name="id" select="concat('desc4290', position())"/> This is the initiating arrow</desc>
                                    </path>
                                    <!-- arrow head client to server -->
                                    <path
                                        d="m -1076.6057,-278.23492 0.2428,9.99706 c 3.8451,-1.75975 7.6902,-3.51949 11.5354,-5.27924 0,-0.002 0,-0.002 0,-0.002 0,0 0,0 -0,-0.002 -3.926,-1.57108 -7.852,-3.14216 -11.7781,-4.71324 z"
                                        style="fill:#000000;fill-rule:evenodd;stroke:none">
                                        <xsl:attribute name="id" select="concat('pathTriangleC2S_', position())"/>
                                        <xsl:attribute name="d"
                                            select="concat('m ', -1435 + $arrowLength, ',', -387.5 + (position()*104.5), ' 0.2428,9.99706 c 3.8451,-1.75975 7.6902,-3.51949 11.5354,-5.27924 0,-0.002 0,-0.002 0,-0.002 0,0 0,0 -0,-0.002 -3.926,-1.57108 -7.852,-3.14216 -11.7781,-4.71324 z')"
                                        />
                                    </path>
                                </g>
                            </xsl:for-each>

                            <!-- Server bar -->
                            <rect y="-330" x="-1035" height="330" width="10" id="rectServerBar"
                                style="fill:#c4e1ff;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:0.37758133;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none">
                                <xsl:attribute name="x" select="-1425 + $arrowLength"/>
                                <xsl:attribute name="height" select="10 + $amountMep*104"/>
                                <desc id="desc2864">Server bar</desc>
                            </rect>
                            <!-- Server box to bar line -->
                            <path style="fill:none;stroke:#000000;stroke-width:1px;stroke-linecap:butt;stroke-linejoin:miter;stroke-opacity:1"
                                d="m -1020, -360 v 30" id="path2872">
                                <xsl:attribute name="d" select="concat('m ', (-1425 + $arrowLength + 5) , ', -360 v 30')"/>
                            </path>
                            <!-- Client bar -->
                            <rect y="-330" x="-1435" height="330" width="10" id="rectClientBar"
                                style="fill:#c4e1ff;fill-opacity:1;stroke:#000000;stroke-width:0.35658869;stroke-miterlimit:4;stroke-opacity:1;stroke-dasharray:none">
                                <xsl:attribute name="height" select="10 + $amountMep*104"/>
                                <desc id="desc2880">Client bar</desc>
                            </rect>
                        </g>
                    </svg>
                </xsl:result-document>
            </xsl:if>

        </xsl:for-each>
    </xsl:template>

</xsl:stylesheet>
