#!/bin/sh

# -----------------------------------------
# --  set defaults                       --
# -----------------------------------------

# These are used on the commandline
export inputDir=./mep
export outputDir=../../wsdl

# These are used on the commando line and must contain a forward slash in path
export jarDir=../lib
export xslDir=.

# -------------------------------------------
# --  use input params instead of defaults --
# --  if given                             --
# -------------------------------------------

if [ ! $1 = '' ]; then export inputDir=$1; fi
if [ ! $2 = '' ]; then export outputDir=$2; fi
if [ ! $5 = '' ]; then export jarDir=$5; fi
if [ ! $6 = '' ]; then export xslDir=$6; fi


echo "Input directory                 = $inputDir"
echo "Output directory                = $outputDir"
echo "Java jar path                   = $jarDir"
echo "XSL path                        = $xslDir"

# -------------------------------------------
# --  check input and output dirs          --
# --                                       --
# -------------------------------------------

if [ ! -e "$inputDir" ]; then 
    echo ERROR The input directory \'${inputDir}\' does not exist or is empty!
    exit
fi

if [ "$inputDir" = "$outputDir" ]; then
    echo ERROR The input directory must not be equal to the output directory!
    exit
fi

if [ ! -e "$outputDir" ]; then 
    echo "\nCreating output directory $outputDir..."
    echo "-----------------------\n"
    mkdir "$outputDir"
fi

if [ ! -e "$outputDir-GBK" ]; then 
    echo "\nCreating output directory $outputDir-GBK..."
    echo "-----------------------\n"
    mkdir "$outputDir-GBK"
fi

if [ ! -e "$outputDir-GBP" ]; then 
    echo "\nCreating output directory $outputDir-GBP..."
    echo "-----------------------\n"
    mkdir "$outputDir-GBP"
fi

if [ ! -e "$outputDir-GBO" ]; then 
    echo "\nCreating output directory $outputDir-GBO..."
    echo "-----------------------\n"
    mkdir "$outputDir-GBO"
fi

# -------------------------------------------
# --                                       --
# --  generate the wsdls                   --
# --  for standard GBZ / GBK / GBP         --
# -------------------------------------------

echo
echo Transforming input files for standard GBZ / GBK / GBP WSDLs...
for file in `ls ${inputDir}/SeparateWSDL.xml`
    do java -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/MakeWsdl_ZimClient.xsl
done

# -------------------------------------------
# --  generate graphics                    --
# --                                       --
# --                                       --
# -------------------------------------------

echo
echo Generating the graphics for GBZ/GBK/GBP/GBO...
for file in `ls ${inputDir}/SeparateWSDL.xml`
    do java -Djava.awt.headless=true -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/MakeSVG_ZimClient.xsl
done
echo
echo Converting svg files to png...
for file in `ls ${outputDir}/graphics/*.svg`
    do java -Djava.awt.headless=true -jar ${jarDir}/batik-1.7/batik-rasterizer.jar $file
done
for file in `ls ${outputDir}-GBK/graphics/*.svg`
    do java -Djava.awt.headless=true -jar ${jarDir}/batik-1.7/batik-rasterizer.jar $file
done
for file in `ls ${outputDir}-GBP/graphics/*.svg`
    do java -Djava.awt.headless=true -jar ${jarDir}/batik-1.7/batik-rasterizer.jar $file
done
for file in `ls ${outputDir}-GBO/graphics/*.svg`
    do java -Djava.awt.headless=true -jar ${jarDir}/batik-1.7/batik-rasterizer.jar $file
done
echo

echo Deleting svg files...
rm ${outputDir}/graphics/*.svg
rm ${outputDir}-GBK/graphics/*.svg
rm ${outputDir}-GBP/graphics/*.svg
rm ${outputDir}-GBO/graphics/*.svg

# -------------------------------------------
# --                                       --
# --  generate the htmls                   --
# --                                       --
# -------------------------------------------

echo Generating html files for GBZ / GBK / GBP / GBO ...
# probably you don't want to generate a new index file based on the SeparateWSDL.xml, so commented out next command
#for file in `ls ${inputDir}/SeparateWSDL.xml`
#    do java -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/MakeIndexHTML_ZimClient.xsl
#done
for file in `ls ${inputDir}/*_wsdls.xml`
    do java -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/MakeIndexHTML_ZimClient.xsl
done

# The resolver.jar is needed here because saxon cannot resolve the doctype dtd (in the DOCTYPE statement in input html) from the commandline. 
# DOCTYPE statement is needed in html for Internet Explorer to handle the css stylesheets.
for file in `ls ${inputDir}/SeparateWSDL.xml`
    do java -Djava.awt.headless=true -cp .:${jarDir}/saxon-9/saxon9.jar:${jarDir}/xml-commons-resolver-1.2/resolver.jar net.sf.saxon.Transform -x:org.apache.xml.resolver.tools.ResolvingXMLReader -s:$file -xsl:MakeHTML_ZimClient.xsl
done

echo
echo Done with this batch file...


