@echo off

:: -------------------------------------------
:: --  set defaults                      --
:: --                                       --
:: -------------------------------------------

:: These are used on the commandline
set inputDir=mep
set outputDir=..\..\wsdl

:: These are used in windows and must thus contain backslash in path
set jarDir=..\lib\
set xslDir=

:: -------------------------------------------
:: --  use input params instead of defaults --
:: --  if given                             --
:: -------------------------------------------

if not (%1)==() set inputDir=%1
if not (%2)==() set outputDir=%2
if not (%3)==() set jarDir=%3
if not (%4)==() set xslDir=%4

echo.Input directory                 = [%inputdir%]
echo.Output directory                = [%outputDir%]
echo.Java jar directory              = [%jarDir%]
echo.xsl directory                   = [%xslDir%]

:: -------------------------------------------
:: --  check input and output dirs          --
:: --                                       --
:: -------------------------------------------

if not exist "%inputdir%" echo.ERROR The input directory [%inputDir%] does not exist or is empty! Cannot proceed. & pause & exit /B

if exist %outputDir% echo.WARNING The output directory [%outputDir%] already exists! Please check if this does not pollute your results! You may need to empty the output directory: [%outputDir%] first.

if not exist "%outputDir%" (
    echo.
    echo Creating output directory: "%outputDir%" ...
    echo -----------------------
    echo.
    mkdir "%outputDir%"
) else (
    echo.
    echo Removing html and graphics contents of output directory: "%outputDir%" ...
    echo -----------------------
    echo.
    del /Q "%outputDir%\*.html"
    del /Q "%outputDir%\graphics\*.*"
)

if exist "%inputDir%\GBK_wsdls.xml" (
    if not exist "%outputDir%-GBK" (
        echo.
        echo Creating output directory: "%outputDir%-GBK" ...
        echo -----------------------
        echo.
        mkdir "%outputDir%-GBK"
    ) else (
        echo.
        echo Removing html and graphics contents of output directory: "%outputDir%-GBK" ...
        echo -----------------------
        echo.
        del /Q "%outputDir%-GBK\*.html"
        del /Q "%outputDir%-GBK\graphics\*.*"
    )
)

if exist "%inputDir%\GBP_wsdls.xml" (
    if not exist "%outputDir%-GBP" (
        echo.
        echo Creating output directory: "%outputDir%-GBP" ...
        echo -----------------------
        echo.
        mkdir "%outputDir%-GBP"
    ) else (
        echo.
        echo Removing html and graphic contents of output directory: "%outputDir%-GBP" ...
        echo -----------------------
        echo.
        del /Q "%outputDir%-GBP\*.html"
        del /Q "%outputDir%-GBP\graphics\*.*"
    )
)

if exist "%inputDir%\GBK_wsdls.xml" (
    if not exist "%outputDir%-GBO" (
        echo.
        echo Creating output directory: "%outputDir%-GBO" ...
        echo -----------------------
        echo.
        mkdir "%outputDir%-GBO"
    ) else (
        echo.
        echo Removing html and graphic contents of output directory: "%outputDir%-GBO" ...
        echo -----------------------
        echo.
        del /Q "%outputDir%-GBO\*.html"
        del /Q "%outputDir%-GBO\graphics\*.*"
    )
)

:: -------------------------------------------
:: --                                       --
:: --  generate the wsdls                   --
:: --  for GBZ, GBK and GBP                 --
:: -------------------------------------------

echo.Transforming input files for GBZ / GBK / GBP / GBO WSDL's...
for %%F in (%inputDir%\*_wsdls.xml) do java -jar %jarDir%saxon-9\saxon9.jar -s:"%%F" -xsl:%xslDir%MakeWsdl_ZimClient.xsl

:: -------------------------------------------
:: --  generate graphics                    --
:: --                                       --
:: --                                       --
:: -------------------------------------------

echo.Generating the graphics for GBZ/GBK/GBP/GBO
for %%F in (%inputDir%\*_wsdls.xml) do java -jar %jarDir%saxon-9\saxon9.jar -s:"%%F" -xsl:%xslDir%MakeSVG_ZimClient.xsl

echo.
echo.Converting svg files to png...
for %%F in (%outputDir%\graphics\*.svg) do java -jar %jarDir%batik-1.7\batik-rasterizer.jar %%F

if exist "%inputDir%\GBK_wsdls.xml" (
    for %%F in (%outputDir%-GBK\graphics\*.svg) do java -jar %jarDir%batik-1.7\batik-rasterizer.jar %%F
)
if exist "%inputDir%\GBP_wsdls.xml" (
    for %%F in (%outputDir%-GBP\graphics\*.svg) do java -jar %jarDir%batik-1.7\batik-rasterizer.jar %%F
)
if exist "%inputDir%\GBO_wsdls.xml" (
    for %%F in (%outputDir%-GBO\graphics\*.svg) do java -jar %jarDir%batik-1.7\batik-rasterizer.jar %%F
)

echo.Deleting svg files...
del %outputDir%\graphics\*.svg

if exist "%inputDir%\GBK_wsdls.xml" (
    del %outputDir%-GBK\graphics\*.svg
)
if exist "%inputDir%\GBP_wsdls.xml" (
    del %outputDir%-GBP\graphics\*.svg
)
if exist "%inputDir%\GBO_wsdls.xml" (
    del %outputDir%-GBO\graphics\*.svg
)
echo.

:: -------------------------------------------
:: --                                       --
:: --  generate the htmls                   --
:: --                                       --
:: -------------------------------------------

echo.Generating html files for GBZ / GBK / GBP /GBO ...
for %%F in (%inputDir%\*_wsdls.xml) do java -jar %jarDir%saxon-9\saxon9.jar -s:"%%F" -xsl:%xslDir%MakeIndexHTML_ZimClient.xsl
:: The resolver.jar is needed here because saxon cannot resolve the doctype dtd (in the DOCTYPE statement in input html) from the commandline. 
:: DOCTYPE statement is needed in html for Internet Explorer to handle the css stylesheets.
for %%F in (%inputDir%\*_wsdls.xml) do java -cp .;%jarDir%saxon-9\saxon9.jar;%jarDir%xml-commons-resolver-1.2\resolver.jar net.sf.saxon.Transform -x:org.apache.xml.resolver.tools.ResolvingXMLReader -s:"%%F" -xsl:MakeHTML_ZimClient.xsl

echo
echo.Done with this batch file...


