#!/bin/sh

# -----------------------------------------
# --  set defaults                       --
# -----------------------------------------

# These are used on the command line
export inputDir=./mep
export outputDir=../../wsdl

# These are used on the command line and must contain a forward slash in path
export jarDir=../lib
export xslDir=.

# -------------------------------------------
# --  use input params instead of defaults --
# --  if given                             --
# -------------------------------------------

if [ ! $1 = '' ]; then export inputDir=$1; fi
if [ ! $2 = '' ]; then export outputDir=$2; fi
if [ ! $3 = '' ]; then export jarDir=$3; fi
if [ ! $4 = '' ]; then export xslDir=$4; fi


echo "Input directory                 = ${inputDir}"
echo "Output directory                = ${outputDir}"
echo "Java jar path                   = $jarDir"
echo "XSL path                        = $xslDir"

# -------------------------------------------
# --  check input and output dirs          --
# --                                       --
# -------------------------------------------

if [ ! -e "${inputDir}" ]; then 
    echo ERROR The input directory \'${inputDir}\' does not exist or is empty!
    exit
fi

if [ "${inputDir}" = "${outputDir}" ]; then
    echo ERROR The input directory must not be equal to the output directory!
    exit
fi

if [ -e "${inputDir}/GBZ_wsdls.xml" ]; then
    if [ ! -e "${outputDir}" ]; then 
        echo "\nCreating output directory ${outputDir} ..."
        echo "-----------------------\n"
        mkdir "${outputDir}"
    else
        echo "\nRemoving html and graphics contents of output directory ${outputDir} ..."
        echo "-----------------------\n"
        rm ${outputDir}/*.html
        rm ${outputDir}/graphics/*.*
    fi
fi

if [ -e "${inputDir}/GBK_wsdls.xml" ]; then 
    if [ ! -e "${outputDir}-GBK" ]; then 
        echo "\nCreating output directory ${outputDir}-GBK ..."
        echo "-----------------------\n"
        mkdir "${outputDir}-GBK"
    else
        echo "\nRemoving html and graphics contents of output directory ${outputDir}-GBK ..."
        echo "-----------------------\n"
        rm ${outputDir}-GBK/*.html
        rm ${outputDir}-GBK/graphics/*.*
    fi
fi

if [ -e "${inputDir}/GBP_wsdls.xml" ]; then
    if [ ! -e "${outputDir}-GBP" ]; then 
        echo "\nCreating output directory ${outputDir}-GBP ..."
        echo "-----------------------\n"
        mkdir "${outputDir}-GBP"
    else
        echo "\nRemoving html and graphics contents of output directory ${outputDir}-GBP ..."
        echo "-----------------------\n"
        rm ${outputDir}-GBP/*.html
        rm ${outputDir}-GBP/graphics/*.*
    fi
fi

if [ -e "${inputDir}/GBO_wsdls.xml" ]; then
    if [ ! -e "${outputDir}-GBO" ]; then 
        echo "\nCreating output directory ${outputDir}-GBO ..."
        echo "-----------------------\n"
        mkdir "${outputDir}-GBO"
    else
        echo "\nRemoving html and graphics contents of output directory ${outputDir}-GBO ..."
        echo "-----------------------\n"
        rm ${outputDir}-GBO/*.html
        rm ${outputDir}-GBO/graphics/*.*
    fi
fi

# -------------------------------------------
# --                                       --
# --  generate the wsdls                   --
# --  for standard GBZ / GBK / GBP         --
# -------------------------------------------

echo
echo Transforming input files for standard GBZ / GBK / GBP /GBO WSDLs...
for file in `ls ${inputDir}/*_wsdls.xml`
    do java -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/MakeWsdl_ZimClient.xsl outputDir=${outputPath}
done

# -------------------------------------------
# --  generate graphics                    --
# --                                       --
# --                                       --
# -------------------------------------------

echo
echo Generating the graphics for GBZ/GBK/GBP/GBO...
for file in `ls ${inputDir}/*_wsdls.xml`
    do java -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/MakeSVG_ZimClient.xsl outputDir=${outputPath}
done

echo
echo Converting svg files to png...
for file in `ls ${outputDir}/graphics/*.svg`
    do java -Djava.awt.headless=true -jar ${jarDir}/batik-1.7/batik-rasterizer.jar $file
done
if [ -e "${inputDir}/GBK_wsdls.xml" ]; then
    for file in `ls ${outputDir}-GBK/graphics/*.svg`
        do java -Djava.awt.headless=true -jar ${jarDir}/batik-1.7/batik-rasterizer.jar $file
    done
fi
if [ -e "${inputDir}/GBP_wsdls.xml" ]; then
    for file in `ls ${outputDir}-GBP/graphics/*.svg`
        do java -Djava.awt.headless=true -jar ${jarDir}/batik-1.7/batik-rasterizer.jar $file
    done
fi
if [ -e "${inputDir}/GBO_wsdls.xml" ]; then
    for file in `ls ${outputDir}-GBO/graphics/*.svg`
        do java -Djava.awt.headless=true -jar ${jarDir}/batik-1.7/batik-rasterizer.jar $file
    done
fi
echo

echo Deleting svg files...
rm ${outputDir}/graphics/*.svg
if [ -e "${inputDir}/GBK_wsdls.xml" ]; then
    rm ${outputDir}-GBK/graphics/*.svg
fi
if [ -e "${inputDir}/GBP_wsdls.xml" ]; then
    rm ${outputDir}-GBP/graphics/*.svg
fi
if [ -e "${inputDir}/GBO_wsdls.xml" ]; then
    rm ${outputDir}-GBO/graphics/*.svg
fi
echo

# -------------------------------------------
# --                                       --
# --  generate the htmls                   --
# --                                       --
# -------------------------------------------

echo Generating html files for GBZ / GBK / GBP / GBO ...
for file in `ls ${inputDir}/*_wsdls.xml`
    do java -jar ${jarDir}/saxon-9/saxon9.jar -s:$file -xsl:${xslDir}/MakeIndexHTML_ZimClient.xsl
done
# The resolver.jar is needed here because saxon cannot resolve the doctype dtd (in the DOCTYPE statement in input html) from the commandline. 
# DOCTYPE statement is needed in html for Internet Explorer to handle the css stylesheets.
for file in `ls ${inputDir}/*_wsdls.xml`
    do java -Djava.awt.headless=true -cp .:${jarDir}/saxon-9/saxon9.jar:${jarDir}/xml-commons-resolver-1.2/resolver.jar net.sf.saxon.Transform -x:org.apache.xml.resolver.tools.ResolvingXMLReader -s:$file -xsl:MakeHTML_ZimClient.xsl
done

echo
echo Done with this batch file...


