<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0" exclude-result-prefixes="#all"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
    <!-- 
        This stylesheet creates the main html index for the documentation of the XML distribution.
        The content is organised into five tabs:
        1. Introduction
        2. WSDL, index of all wsdl files in the WSDL directory
        3. Schemas, index of the XML schemas
        4. Vocabulary, index of of files in the vocab directory
        5. Directory Overview, index of the XML distribution with description of directories.
    
        This stylesheet requires the Saxon XSLT2 processor 9 HE
        
        Copyright notice .....
        
        Authors ....?
    -->
    <xsl:output method="html" indent="yes" version="4.01" encoding="UTF-8" doctype-public="-//W3C//DTD HTML 4.01//EN"
        doctype-system="http://www.w3.org/TR/html4/strict.dtd"/>
    <xsl:template match="/">
        <xsl:comment> This file was generated by report.xsl </xsl:comment>
        <html>
            <head>
                <title>Validatierapport van <xsl:value-of select="/*/@creationDate"/></title>
                <xsl:call-template name="addAssetsHeader"/>
            </head>
            <body>
                <!-- page header -->
                <table width="100%">
                    <tr>
                        <td valign="bottom">
                            <h1>Validatierapport van <xsl:value-of select="/*/@creationDate"/></h1>
                        </td>
                        <td align="right">
                            <div class="logo"/>
                        </td>
                    </tr>
                </table>
                <p>
                    <input type="checkbox" checked="true" name="Toon waarschuwingen" onclick="toggleByClassName(this,'warning');">Toon waarschuwingen</input>
                </p>
                <!-- Spry tabbed panels -->
                <div id="TabbedPanels2" class="TabbedPanels">
                    <!-- tab labels -->
                    <ul class="TabbedPanelsTabGroup">
                        <xsl:for-each select="/*/category">
                            <li class="TabbedPanelsTab" tabindex="{position()-1}" style="font-size:14px"
                                title="{concat(count(file[div]),' bestanden met één of meer meldingen, totaal ',count(file/div),' meldingen')}">
                                <xsl:value-of select="concat('(',count(file[div]),') ')"/>
                                <xsl:value-of select="@name"/>
                            </li>
                        </xsl:for-each>
                    </ul>
                    <!-- tab Group -->

                    <div class="TabbedPanelsContentGroup">
                        <xsl:for-each select="/*/category">
                            <div class="TabbedPanelsContent">
                                <table>
                                    <tr>
                                        <td class="content">
                                            <table>
                                                <tr>
                                                    <td>
                                                        <div class="level2">
                                                            <div class="paragraph">Hieronder een overzicht van alle meldingen met betrekking tot
                                                                    <xsl:value-of select="@name"/>.</div>
                                                            <xsl:call-template name="buildFileList"/>
                                                        </div>
                                                    </td>
                                                </tr>
                                            </table>
                                        </td>
                                    </tr>
                                </table>
                            </div>
                        </xsl:for-each>
                    </div>
                </div>
                <xsl:call-template name="addAssetsBottom"/>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="buildFileList">
        <table class="values" id="{replace(@name,' ','_')}List">
            <thead>
                <tr>
                    <th class="larger">Bestand/map</th>
                    <th class="larger">Meldingen</th>
                </tr>
            </thead>
            <tbody>
                <xsl:for-each select="file[div]">
                    <tr>
                        <td class="value">
                            <xsl:if test="count(div) = count(div[@class='warning'])">
                                <xsl:attribute name="class" select="'value warning'"/>
                            </xsl:if>
                            <xsl:element name="a">
                                <xsl:attribute name="href" select="concat(@dir,'/',@name)"/>
                                <xsl:value-of select="@name"/>
                            </xsl:element>
                            <xsl:if test="@visioEntryPointName">
                                <xsl:element name="br"/>
                                <xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
                                <xsl:value-of select="@visioEntryPointName"/>
                            </xsl:if>
                        </td>
                        <td class="value">
                            <xsl:copy-of select="div"/>
                        </td>
                    </tr>
                </xsl:for-each>
            </tbody>
        </table>
    </xsl:template>

    <xsl:template name="addAssetsHeader">
        <script src="../../css/SpryTabbedPanels.js" type="text/javascript"/>
        <link href="../../css/nictiz.css" type="text/css" rel="stylesheet"/>
        <link href="../../css/SpryTabbedPanels.css" rel="stylesheet" type="text/css"/>
        <script src="../../css/SpryURLUtils.js" type="text/javascript"/>
        <script src="../../css/gs_sortable.js" type="text/javascript"/>
        <script type="text/javascript">
            <xsl:comment>
            function toggle(toggled,toggler) {
                if (document.getElementById) {
                    var currentStyle = document.getElementById(toggled).style;
                    var togglerStyle = document.getElementById(toggler).style;
                    if (currentStyle.display == "block"){
                        currentStyle.display = "none";
                        togglerStyle.backgroundImage = "url(css/trClosed.gif)";
                    } else {
                        currentStyle.display = "block";
                        togglerStyle.backgroundImage = "url(css/trOpen.gif)";
                    }
                    return false;
                } else {
                    return true;
                }
            }
            </xsl:comment>
        </script>
        <script type="text/javascript">
            <xsl:comment>
                <xsl:for-each select="/*/category">
                var TSort_Data = new Array ('<xsl:value-of select="concat(replace(@name,' ','_'),'List')"/>', 'h', 's');
                var TSort_Initial = 0;
                var TSort_Classes = new Array ('plain', 'alternate');
                tsRegister();
                </xsl:for-each>
            </xsl:comment>
        </script>
        <script type="text/javascript">
            <xsl:comment>
            function getElementsByClassName(node,className) {
                if (node.getElementsByClassName) {
                    return node.getElementsByClassName(className);
                } else {
                    return (
                        function getElementsByClass(className,node) {
                            if ( node == null ) {
                                node = document;
                            }
                            var classElements = [];
                            els = node.getElementsByTagName("*");
                            elsLen = els.length;
                            pattern = new RegExp("(^|\\s)"+className+"(\\s|$)");
                            
                            for (i = 0, j = 0; i &lt; elsLen; i++) {
                               if ( pattern.test(els[i].className) ) {
                                  classElements[j] = els[i];
                                  j++;
                               }
                            }
                            return classElements;
                    })(className, node);
                }
            }
            </xsl:comment>
        </script>
        <script type="text/javascript">
            <xsl:comment>
             function toggleByClassName(boxName,className) {
                 var elements = getElementsByClassName(document, className);
                 n = elements.length;
                 for (var i = 0; i &lt; n; i++) {
                     var e = elements[i];
                     if (boxName.checked == true) {
                         e.style.display = 'block';
                     } else {
                        e.style.display = 'none';
                     }
                 }
             }
            </xsl:comment>
        </script>
        <style type="text/css">
            .warning {}
            .error { background-color: OrangeRed; color: white; font-weight: bold; }
        </style>
    </xsl:template>

    <xsl:template name="addAssetsBottom">
        <script type="text/javascript">
          // Grabs the values of the URL parameters for the current URL.
          var params = Spry.Utils.getLocationParamsAsObject();
        </script>

        <script type="text/javascript">
           var TabbedPanels2 = new Spry.Widget.TabbedPanels("TabbedPanels2");
        </script>
    </xsl:template>
</xsl:stylesheet>
