<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl" xmlns:xhtml="http://www.w3.org/1999/xhtml" xmlns:sch="http://purl.oclc.org/dsdl/schematron"
    xmlns:File="java:java.io.File" xmlns:hl7="urn:hl7-org:v3" exclude-result-prefixes="#all" version="2.0">
    <xd:doc scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Created on:</xd:b> Jul 4, 2011</xd:p>
            <xd:p><xd:b>Author:</xd:b> ahenket</xd:p>
            <xd:p/>
        </xd:desc>
    </xd:doc>

    <xsl:output indent="yes"/>

    <!-- Set the language code for messages -->
    <xsl:param name="langCode">en</xsl:param>

    <xsl:param name="inputDir" select="'../../..'"/>
    <xsl:param name="inputDirXML" select="concat($inputDir,'/XML')"/>
    <xsl:param name="inputDirSchemas" select="concat($inputDirXML,'/schemas')"/>
    <xsl:param name="inputDirSchematron" select="concat($inputDirXML,'/schematron')"/>
    <xsl:param name="inputDirVocab" select="concat($inputDirXML,'/vocab')"/>
    <xsl:param name="schemaInfoFile" select="'../resolveIncludes/xmlschemainfo.xml'"/>
    <xsl:variable name="schemaInfoFileNormalized" select="replace($schemaInfoFile,'\\','/')"/>
    <xsl:variable name="interactionFile" select="concat($inputDirVocab,'/2.16.840.1.113883.1.6.xml')"/>
    <xsl:variable name="inputDirsWSDL">
        <xsl:element name="dirs">
            <xsl:variable name="dir" select="File:new(resolve-uri($inputDirXML))"/>
            <xsl:variable name="files" select="File:list($dir)"/>
            <xsl:for-each select="$files">
                <xsl:if test="starts-with(.,'wsdl')">
                    <xsl:call-template name="buildWsdlFileList">
                        <xsl:with-param name="startDir" select="concat($inputDirXML,'/',.)"/>
                    </xsl:call-template>
                </xsl:if>
            </xsl:for-each>
        </xsl:element>
    </xsl:variable>
    <xsl:variable name="hmd">
        <files>
            <file name="MCAI_MT700201" rmim="MCAI_RM700200"/>
            <file name="MCAI_MT700201_OPT_OV" rmim="MCAI_RM700200"/>
            <file name="MCAI_MT900001" rmim="MCAI_RM900000"/>
            <file name="MFMI_MT700701" rmim="MFMI_RM700700"/>
            <file name="MFMI_MT700701_OPT_OV" rmim="MFMI_RM700700"/>
            <file name="MFMI_MT700702" rmim="MFMI_RM700700"/>
            <file name="MFMI_MT700702_OPT_OV" rmim="MFMI_RM700700"/>
            <file name="MFMI_MT700711" rmim="MFMI_RM700710"/>
            <file name="MFMI_MT700712" rmim="MFMI_RM700710"/>
            <file name="MFMT_MT002001" rmim="MFMT_RM002000"/>
            <file name="MFMT_MT002001NL02" rmim="MFMT_RM002000NL02"/>
            <file name="MFMT_MT002002" rmim="MFMT_RM002000"/>
            <file name="MFMT_MT002002NL02" rmim="MFMT_RM002000NL02"/>
            <file name="PRPM_MT405010NL" rmim="PRPM_RM405000NL"/>
            <file name="PRPM_MT406010NL" rmim="PRPM_RM406000NL"/>
            <file name="PRPM_MT906010NL" rmim="PRPM_RM906000NL"/>
            <file name="PRPM_MT906110NL" rmim="PRPM_RM901000NL"/>
            <file name="QUQI_MT020001" rmim="QUQI_RM020000"/>
            <file name="QUQI_MT021001" rmim="QUQI_RM021000"/>
            <file name="QUQI_MT021001_OPT_OV" rmim="QUQI_RM021000"/>
            <file name="QUQI_MT120001" rmim="QUQI_RM120000"/>
        </files>
    </xsl:variable>

    <xsl:template match="/">
        <xsl:processing-instruction name="xml-stylesheet">type="text/xsl" href="report.xsl"</xsl:processing-instruction>
        <xsl:comment> This file was generated by xmlFolderVerification.xsl </xsl:comment>
        <xsl:element name="files">
            <xsl:attribute name="creationDate" select="format-dateTime(current-dateTime(), '[Y]-[M,2]-[D,2] [H,2]:[m,2]:[s,2]')"/>
            <xsl:call-template name="checkWebservices"/>
            <xsl:call-template name="checkSchemas"/>
            <xsl:call-template name="checkSchematrons"/>
        </xsl:element>
    </xsl:template>

    <!--
        Schema checks
        1. Check if schema file name conforms to AAAA_MTnnnnnnAA(nn)? or AAAA_INnnnnnnAA(nn)?
        2. If schema defines an interaction, check if the root element matches the file name
        3. If schema defines an interaction, check if there is a schematron file by the same name
        4. If schema defines a message type/CMET, check if it is used in an interaction
        5. If schema defines a message type/CMET, check if the complexTypes start with "file name" and a dot
        6. If schema defines a message type/CMET, check if there is exactly one matching visio .xsd and .xml file
           in any img directory above $inputDirXML
           Schema file name "*_MT*.xsd" should match with "*_RM*.vsd" and "*_RM*.xml"
        7. If schema defines a message type/CMET, check if entry point ID matches base file name of visio xml
        8. If schema defines an interaction, check if it is used in any WSDL file
        9. If a schema defines an include, check if it exists
        10. If a schema defines an interaction, check if it is defined in the interaction vocab file
    -->
    <xsl:template name="checkSchemas">
        <xsl:variable name="visioxmlfiles">
            <xsl:element name="files">
                <xsl:call-template name="findVisioFiles">
                    <xsl:with-param name="startDir" select="$inputDir"/>
                </xsl:call-template>
                <xsl:call-template name="findVisioFiles">
                    <xsl:with-param name="startDir" select="concat($inputDir,'/../../trunk')"/>
                </xsl:call-template>
            </xsl:element>
        </xsl:variable>
        <xsl:result-document href="visiomodelindex.xml" indent="yes" exclude-result-prefixes="#all">
            <xsl:comment> This file was generated by xmlFolderVerification.xsl </xsl:comment>
            <xsl:copy-of select="$visioxmlfiles"/>
        </xsl:result-document>
        <xsl:variable name="dir" select="File:new(resolve-uri($inputDirSchemas))"/>
        <xsl:variable name="files" select="File:list($dir)"/>
        <xsl:element name="category">
            <xsl:attribute name="name" select="'XML Schemas'"/>
            <xsl:for-each select="$files">
                <xsl:variable name="fileName" select="."/>
                <xsl:variable name="fullFileName" select="concat($inputDirSchemas,'/',$fileName)"/>
                <xsl:variable name="baseFileName" select="tokenize($fileName,'\.')[last()-1]"/>
                <xsl:if test="not(starts-with($fileName,'.'))">
                    <xsl:element name="file">
                        <xsl:attribute name="name" select="$fileName"/>
                        <xsl:attribute name="dir" select="$inputDirSchemas"/>
                        <xsl:variable name="baseRmimFileName">
                            <xsl:choose>
                                <xsl:when test="$hmd//file[@name=$baseFileName]">
                                    <xsl:value-of select="$hmd//file[@name=$baseFileName]/@rmim"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="replace($baseFileName,'_MT','_RM')"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <xsl:if test="$visioxmlfiles//file[@name=concat($baseRmimFileName,'.xml')][1]">
                            <xsl:variable name="visioPath" select="$visioxmlfiles//file[@name=concat($baseRmimFileName,'.xml')][1]/@path"/>
                            <xsl:variable name="visioName" select="$visioxmlfiles//file[@name=concat($baseRmimFileName,'.xml')][1]/@name"/>
                            <xsl:attribute name="visioEntryPointName"
                                select="document(concat($visioPath,'/',$visioName))//hl7model/pages[1]/page[1]/entryPoint[1]/@name"/>
                        </xsl:if>
                        <xsl:variable name="fileType">
                            <!-- Note: do not fail MCAI_MT700201_OPT_OV.xsd and other funky postfixes here -->
                            <xsl:choose>
                                <xsl:when test="matches($fileName,'^[A-Z]{4}_MT[0-9]([A-Z]{2})?')">
                                    <xsl:text>messagetype</xsl:text>
                                </xsl:when>
                                <xsl:when test="matches($fileName,'^[A-Z]{4}_IN[0-9]([A-Z]{2})?')">
                                    <xsl:text>interaction</xsl:text>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:text>unknown</xsl:text>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>

                        <!-- 1. Check if schema file name conforms to AAAA_MTnnnnnnAA(nn)? or AAAA_INnnnnnnAA(nn)? -->
                        <xsl:if test="not(matches($fileName,'^[A-Z]{4}((_MT)|(_IN))[0-9]{6}([A-Z]{2}([0-9]{2})?)?\.xsd$'))">
                            <div class="warning">
                                <xsl:call-template name="outputLocalizedMessage">
                                    <xsl:with-param name="number">1</xsl:with-param>
                                </xsl:call-template>
                            </div>
                        </xsl:if>

                        <!-- 2. If schema defines an interaction, check if the root element matches the file name -->
                        <!-- 10. If a schema defines an interaction, check if it is defined in the interaction vocab file -->
                        <xsl:if test="$fileType='interaction'">
                            <xsl:variable name="rootElement"
                                select="document($fullFileName)/xs:schema/xs:element[matches(@type,'MCCI_.*\.((Message)|(Batch))')][1]/@name"/>
                            <xsl:if test="not($baseFileName=$rootElement)">
                                <div class="error">
                                    <xsl:call-template name="outputLocalizedMessage">
                                        <xsl:with-param name="number">2</xsl:with-param>
                                    </xsl:call-template>
                                    <xsl:value-of select="$rootElement"/>
                                </div>
                            </xsl:if>
                            <xsl:if test="doc-available($interactionFile) and not(doc($interactionFile)/*/hl7:code[@code=$rootElement][@codeSystem='2.16.840.1.113883.1.6'])">
                                <div class="error">
                                    <xsl:call-template name="outputLocalizedMessage">
                                        <xsl:with-param name="number">19</xsl:with-param>
                                    </xsl:call-template>
                                    <xsl:value-of select="$rootElement"/>
                                </div>
                            </xsl:if>
                        </xsl:if>

                        <!-- 3. If schema defines an interaction, check if there is a schematron file by the same name -->
                        <xsl:variable name="interactionViaDecor">
                            <POOR_IN002150NL/>
                            <PRMM_IN010043NL/>
                            <QUPC_IN443130NL/>
                            <QUPC_IN443131NL/>
                            <QUPC_IN443132NL/>
                            <QUPC_IN443230NL/>
                            <QUPC_IN443231NL/>
                            <QUPC_IN443232NL/>
                            <REPC_IN002120NL/>
                            <REPC_IN002120NL_JGZ/>
                            <REPC_IN002140NL/>
                            <REPC_IN404440NL/>	
                            <REPC_IN404441NL/>	
                            <REPC_IN404442NL/>
                        </xsl:variable>
                        <xsl:if test="$fileType='interaction'">
                            <xsl:if test="not($interactionViaDecor/$baseFileName) and not(doc-available(concat($inputDirSchematron,'/',$baseFileName,'.sch')))">
                                <div class="warning">
                                    <xsl:call-template name="outputLocalizedMessage">
                                        <xsl:with-param name="number">9</xsl:with-param>
                                    </xsl:call-template>
                                    <xsl:value-of select="$inputDirSchematron"/>
                                </div>
                            </xsl:if>
                        </xsl:if>

                        <!-- 8. If schema defines an interaction, check if it is used in any WSDL file -->
                        <xsl:if test="$fileType='interaction'">
                            <xsl:if test="not($inputDirsWSDL//file/include[@name=$fileName])">
                                <div class="warning">
                                    <xsl:call-template name="outputLocalizedMessage">
                                        <xsl:with-param name="number">15</xsl:with-param>
                                    </xsl:call-template>
                                </div>
                            </xsl:if>
                        </xsl:if>
                        
                        <!-- 4. If schema defines a message type/CMET, check if it is used in an interaction -->
                        <!-- in comments because the recursion in finding all usage is broken, so results are unreliable -->
                        <xsl:if test="$fileType='messagetype'">
                            <xsl:if
                                test="count(document($schemaInfoFileNormalized)/*/file[@file=$fileName]/used-in[matches(@file,'^[A-Z]{4}_IN[0-9]{6}')])=0">
                                <div class="warning">
                                    <xsl:call-template name="outputLocalizedMessage">
                                        <xsl:with-param name="number">14</xsl:with-param>
                                    </xsl:call-template>
                                </div>
                            </xsl:if>
                        </xsl:if>

                        <!-- 5. If schema defines a message type/CMET, check if the complexTypes start with "file name" and a dot -->
                        <xsl:if test="$fileType='messagetype'">
                            <xsl:if
                                test="count(document($fullFileName)/xs:schema/xs:complexType) &gt; count(document($fullFileName)/xs:schema/xs:complexType[starts-with(@name,concat($baseFileName,'.'))])">
                                <div class="warning">
                                    <xsl:call-template name="outputLocalizedMessage">
                                        <xsl:with-param name="number">3</xsl:with-param>
                                    </xsl:call-template>
                                </div>
                            </xsl:if>
                        </xsl:if>

                        <!-- 6. If schema defines a message type/CMET, check if there is exactly one matching visio .xsd and .xml file
                                 in any img directory above $inputDirXML
                                 Schema file name "*_MT*.xsd" should match with "*_RM*.vsd" and "*_RM*.xml" -->
                        <xsl:if test="$fileType='messagetype'">
                            <xsl:choose>
                                <xsl:when
                                    test="not($visioxmlfiles//file[@name=concat($baseRmimFileName,'.vsd') or @name=concat($baseRmimFileName,'.xml')])">
                                    <div class="warning">
                                        <xsl:call-template name="outputLocalizedMessage">
                                            <xsl:with-param name="number">4</xsl:with-param>
                                        </xsl:call-template>
                                        <xsl:value-of select="concat('(',$baseRmimFileName,'.vsd/.xml)')"/>
                                    </div>
                                </xsl:when>
                                <xsl:when test="not($visioxmlfiles//file[@name=concat($baseRmimFileName,'.vsd')])">
                                    <div class="warning">
                                        <xsl:call-template name="outputLocalizedMessage">
                                            <xsl:with-param name="number">5</xsl:with-param>
                                        </xsl:call-template>
                                        <xsl:value-of select="concat('(',$baseRmimFileName,'.vsd)')"/>
                                    </div>
                                </xsl:when>
                                <xsl:when test="not($visioxmlfiles//file[@name=concat($baseRmimFileName,'.xml')])">
                                    <div class="warning">
                                        <xsl:call-template name="outputLocalizedMessage">
                                            <xsl:with-param name="number">6</xsl:with-param>
                                        </xsl:call-template>
                                        <xsl:value-of select="concat('(',$baseRmimFileName,'.xml)')"/>
                                    </div>
                                </xsl:when>
                                <xsl:when test="count($visioxmlfiles//file[@name=concat($baseRmimFileName,'.vsd')])&gt;1">
                                    <div class="warning">
                                        <xsl:call-template name="outputLocalizedMessage">
                                            <xsl:with-param name="number">7</xsl:with-param>
                                        </xsl:call-template>
                                        <ol>
                                            <xsl:for-each select="$visioxmlfiles//file[@name=concat($baseRmimFileName,'.vsd')]">
                                                <li>
                                                    <xsl:value-of select="concat(@path,'/',@name)"/>
                                                </li>
                                            </xsl:for-each>
                                        </ol>
                                    </div>
                                </xsl:when>
                            </xsl:choose>
                        </xsl:if>

                        <!-- 7. If schema defines a message type/CMET, check if entry point ID matches base file name of visio xml -->
                        <xsl:if test="$fileType='messagetype'">
                            <xsl:for-each
                                select="$visioxmlfiles//file[@name=concat($baseRmimFileName,'.xml') and not(@name=concat($baseRmimFileName,'_bak.xml'))]">
                                <xsl:variable name="visioEntryPointId"
                                    select="document(concat(@path,'/',@name))//hl7model/pages[1]/page[1]/entryPoint[1]/@id"/>
                                <xsl:choose>
                                    <xsl:when test="not($visioEntryPointId)">
                                        <div class="error">
                                            <xsl:call-template name="outputLocalizedMessage">
                                                <xsl:with-param name="number">17</xsl:with-param>
                                            </xsl:call-template>
                                        </div>
                                    </xsl:when>
                                    <xsl:when test="not($visioEntryPointId=$baseRmimFileName)">
                                        <div class="warning">
                                            <xsl:call-template name="outputLocalizedMessage">
                                                <xsl:with-param name="number">8</xsl:with-param>
                                            </xsl:call-template>
                                            <xsl:call-template name="outputLocalizedMessage">
                                                <xsl:with-param name="number">8a</xsl:with-param>
                                            </xsl:call-template>
                                            <xsl:value-of select="$baseRmimFileName"/>
                                            <xsl:text>. </xsl:text>
                                            <xsl:call-template name="outputLocalizedMessage">
                                                <xsl:with-param name="number">8b</xsl:with-param>
                                            </xsl:call-template>
                                            <xsl:value-of select="$visioEntryPointId"/>
                                            <xsl:text>. </xsl:text>
                                        </div>
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:for-each>
                        </xsl:if>

                        <!-- 9. If a schema defines an include, check if it exists -->
                        <!-- <file name="COCT_MT000003NL.xsd" dir="schemas" hl7type="cmet"> 
                                 <uses file="COCT_MT140007UV.xsd" exists="false"/> 
                        -->
                        <xsl:if test="document($schemaInfoFileNormalized)//file[@file=$fileName]/uses[@exists='false']">
                            <div class="error">
                                <xsl:call-template name="outputLocalizedMessage">
                                    <xsl:with-param name="number">18</xsl:with-param>
                                </xsl:call-template>
                                <xsl:text>(</xsl:text>
                                <xsl:value-of select="document($schemaInfoFileNormalized)//file[@file=$fileName]/uses[@exists='false']/@file"/>
                                <xsl:text>)</xsl:text>
                            </div>
                        </xsl:if>
                    </xsl:element>
                </xsl:if>
            </xsl:for-each>
        </xsl:element>
    </xsl:template>

    <!--
        Schematron checks (just top level)
        1. If schematron checks an interaction (*_IN*.sch), check if there is an XML Schema file that covers it 
        2. Check if first element after root is sch:title
        3. Check if there is a pattern where @is-a equals @id
        4. Check if abstract pattern/rule have @id
    -->
    <xsl:template name="checkSchematrons">
        <xsl:variable name="dir" select="File:new(resolve-uri($inputDirSchematron))"/>
        <xsl:variable name="files" select="File:list($dir)"/>
        <xsl:element name="category">
            <xsl:attribute name="name" select="'Schematrons'"/>
            <xsl:for-each select="$files">
                <xsl:variable name="fileName" select="."/>
                <xsl:variable name="fullFileName" select="concat($inputDirSchematron,'/',$fileName)"/>
                <xsl:variable name="baseFileName" select="tokenize($fileName,'\.')[last()-1]"/>
                <xsl:if test="not(starts-with($fileName,'.')) and ends-with($fileName,'.sch')">
                    <xsl:element name="file">
                        <xsl:attribute name="name" select="$fileName"/>
                        <xsl:attribute name="dir" select="$inputDirSchematron"/>
                        <xsl:variable name="fileType">
                            <!-- Note: do not fail MCAI_MT700201_OPT_OV.xsd and other funky postfixes here -->
                            <xsl:choose>
                                <xsl:when test="matches($fileName,'^[A-Z]{4}_MT[0-9]([A-Z]{2})?')">
                                    <xsl:text>messagetype</xsl:text>
                                </xsl:when>
                                <xsl:when test="matches($fileName,'^[A-Z]{4}_IN[0-9]([A-Z]{2})?')">
                                    <xsl:text>interaction</xsl:text>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:text>unknown</xsl:text>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>

                        <!-- 1. If schematron checks an interaction (*_IN*.sch), check if there is an XML Schema file that covers it -->
                        <xsl:if test="$fileType='interaction'">
                            <xsl:if test="not(doc-available(concat($inputDirSchemas,'/',$baseFileName,'.xsd')))">
                                <div class="warning">
                                    <xsl:call-template name="outputLocalizedMessage">
                                        <xsl:with-param name="number">10</xsl:with-param>
                                    </xsl:call-template>
                                    <xsl:value-of select="$inputDirSchemas"/>
                                </div>
                            </xsl:if>
                        </xsl:if>

                        <!-- 2. Check if first element after root is sch:title -->
                        <xsl:if test="not(document($fullFileName)/sch:schema/sch:*[1][local-name()='title'])">
                            <div class="warning">
                                <xsl:call-template name="outputLocalizedMessage">
                                    <xsl:with-param name="number">11</xsl:with-param>
                                </xsl:call-template>
                            </div>
                        </xsl:if>

                        <!-- 3. Check if there is a pattern where @is-a equals @id -->
                        <xsl:if test="document($fullFileName)/sch:schema/sch:pattern[@is-a=@id]">
                            <div class="error">
                                <xsl:call-template name="outputLocalizedMessage">
                                    <xsl:with-param name="number">12</xsl:with-param>
                                </xsl:call-template>
                                <ol>
                                    <xsl:for-each select="document($fullFileName)/sch:schema/sch:pattern[@is-a=@id]">
                                        <li>
                                            <xsl:text>&lt;</xsl:text>
                                            <xsl:value-of select="local-name()"/>
                                            <xsl:text> is-a="</xsl:text>
                                            <xsl:value-of select="@is-a"/>
                                            <xsl:text>" id="</xsl:text>
                                            <xsl:value-of select="@id"/>
                                            <xsl:text>"</xsl:text>
                                            <xsl:text>/&gt;</xsl:text>
                                        </li>
                                    </xsl:for-each>
                                </ol>
                            </div>
                        </xsl:if>

                        <!-- 4. Check if abstract pattern/rule have @id -->
                        <xsl:if test="document($fullFileName)/sch:schema/sch:pattern[@abstract='true' and not(@id)]">
                            <div class="error">
                                <xsl:call-template name="outputLocalizedMessage">
                                    <xsl:with-param name="number">13</xsl:with-param>
                                </xsl:call-template>
                            </div>
                        </xsl:if>
                    </xsl:element>
                </xsl:if>
            </xsl:for-each>
        </xsl:element>
    </xsl:template>

    <!--
        Webservices checks
        1. Check if included schemas exist
    -->
    <xsl:template name="checkWebservices">
        <xsl:element name="category">
            <xsl:attribute name="name" select="'Webservices'"/>
            <xsl:for-each select="$inputDirsWSDL/dirs/dir">
                <xsl:variable name="fileName" select="tokenize(@name,'/')[last()]"/>
                <xsl:variable name="fullFileName" select="@name"/>
                <xsl:element name="file">
                    <xsl:attribute name="name" select="$fileName"/>
                    <xsl:attribute name="dir" select="$fullFileName"/>
                </xsl:element>
                <xsl:for-each select="file">
                    <xsl:variable name="subfileName" select="@name"/>
                    <xsl:variable name="subfullFileName" select="@path"/>
                    <xsl:element name="file">
                        <xsl:attribute name="name" select="concat($fileName,'/',$subfileName)"/>
                        <xsl:attribute name="dir" select="$subfullFileName"/>
                        <xsl:for-each select="include">
                            <xsl:if test="@exists='false'">
                                <div class="error">
                                    <xsl:call-template name="outputLocalizedMessage">
                                        <xsl:with-param name="number">16</xsl:with-param>
                                    </xsl:call-template>
                                    <xsl:value-of select="concat('(',@path,')')"/>
                                </div>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:element>
                </xsl:for-each>
            </xsl:for-each>
        </xsl:element>
    </xsl:template>

    <!-- Internal recursive function that looks for *.vsd and *.xml under "img" directories -->
    <xsl:template name="findVisioFiles">
        <xsl:param name="startDir"/>
        <xsl:variable name="dir" select="File:new(resolve-uri($startDir))"/>
        <xsl:variable name="files" select="File:list($dir)"/>
        <xsl:message>  [info] Searching for Visio XML in <xsl:value-of select="$startDir"/></xsl:message>
        <xsl:for-each select="$files">
            <xsl:variable name="fileName" select="."/>
            <xsl:variable name="fullFileName" select="concat($startDir,'/',$fileName)"/>
            <xsl:variable name="baseFileName" select="tokenize($fileName,'\.')[last()-1]"/>
            <xsl:if
                test="not(starts-with($fileName,'.') or $fileName='conf' or $fileName='db' or $fileName='EAmodellering' or $fileName='format' or $fileName='hooks' or $fileName='Instructies' or $fileName='locks' or $fileName='hooks' or $fileName='Instructies' or $fileName='XML')">
                <xsl:choose>
                    <xsl:when test="ends-with($fileName,'.vsd')">
                        <xsl:element name="file">
                            <xsl:attribute name="name" select="$fileName"/>
                            <xsl:attribute name="path" select="$startDir"/>
                        </xsl:element>
                        <xsl:if test="doc-available(concat($startDir,'/',$baseFileName,'.xml'))">
                            <xsl:element name="file">
                                <xsl:attribute name="name" select="concat($baseFileName,'.xml')"/>
                                <xsl:attribute name="path" select="$startDir"/>
                            </xsl:element>
                        </xsl:if>
                    </xsl:when>
                    <xsl:when test="not(contains($fileName,'.'))">
                        <xsl:call-template name="findVisioFiles">
                            <xsl:with-param name="startDir" select="$fullFileName"/>
                        </xsl:call-template>
                    </xsl:when>
                </xsl:choose>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>

    <!-- Internal function that builds a list of all wsdl files -->
    <xsl:template name="buildWsdlFileList">
        <xsl:param name="startDir"/>
        <xsl:variable name="dir" select="File:new(resolve-uri($startDir))"/>
        <xsl:variable name="files" select="File:list($dir)"/>
        <xsl:element name="dir">
            <xsl:attribute name="name" select="$startDir"/>
            <xsl:for-each select="$files">
                <xsl:variable name="fileName" select="."/>
                <xsl:variable name="fullFileName" select="concat($startDir,'/',$fileName)"/>
                <xsl:if test="ends-with($fileName,'.wsdl')">
                    <file>
                        <xsl:attribute name="name" select="$fileName"/>
                        <xsl:attribute name="path" select="$fullFileName"/>
                        <xsl:for-each select="document($fullFileName)//xs:include">
                            <include>
                                <xsl:attribute name="name" select="tokenize(@schemaLocation,'/')[last()]"/>
                                <xsl:attribute name="path" select="@schemaLocation"/>
                                <xsl:attribute name="exists" select="doc-available(concat($startDir,'/',@schemaLocation))"/>
                            </include>
                        </xsl:for-each>
                    </file>
                </xsl:if>
            </xsl:for-each>
        </xsl:element>
    </xsl:template>

    <!-- Internal function that emits a message, potentially localized -->
    <xsl:template name="outputLocalizedMessage">
        <xsl:param name="number"/>
        <xsl:choose>
            <xsl:when test="string-length( $langCode ) = 0 or $langCode = 'default'">
                <xsl:attribute name="class" select="document(&quot;&quot;)//xhtml:p[@id=concat(&quot;message-&quot;, $number)]/@class"/>
                <xsl:value-of select="document(&quot;&quot;)//xhtml:p[@id=concat(&quot;message-&quot;, $number)]/text()"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="localizationDocumentFilename">
                    <xsl:value-of select="concat('xmlFolderVerification-messages-', $langCode, '.xhtml')"/>
                </xsl:variable>
                <xsl:variable name="theLocalizedMessage">
                    <xsl:value-of
                        select="document( $localizationDocumentFilename)//xhtml:p[@id=concat(&quot;message-&quot;, $number, &quot;-&quot;, $langCode)]/text()"
                    />
                </xsl:variable>
                <xsl:choose>
                    <!-- if we found any external message with that id, use it -->
                    <xsl:when test=" string-length($theLocalizedMessage) &gt; 0">
                        <xsl:value-of select="$theLocalizedMessage"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <!-- otherwise use the default strings -->
                        <xsl:attribute name="class" select="document(&quot;&quot;)//xhtml:p[@id=concat(&quot;message-&quot;, $number)]/@class"/>
                        <xsl:value-of select="document(&quot;&quot;)//xhtml:p[@id=concat(&quot;message-&quot;, $number)]/text()"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:template>
</xsl:stylesheet>
